# openapi-java-client

Chia RPC
- API version: 1.7.1
  - Build date: 2023-05-11T13:33:44.305253200-04:00[America/New_York]

The Chia node and services come with a JSON RPC API server that allows you to access information and control the services.  These are accessible via HTTPS, WebSockets, or via client SDKs. The ports can be configured in `~/.chia/mainnet/config/config.yaml`.  The RPC ports should not be exposed to the internet. TLS certificates are used to secure the communication  [using mutualTLS](https://github.com/dkackman/chia-api/wiki/Mutual-TLS).
The crawler uses port 8561 by default.

  For more information, please visit [https://www.chia.net/](https://www.chia.net/)

*Automatically generated by the [OpenAPI Generator](https://openapi-generator.tech)*


## Requirements

Building the API client library requires:
1. Java 1.8+
2. Maven (3.8.3+)/Gradle (7.2+)

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn clean install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn clean deploy
```

Refer to the [OSSRH Guide](http://central.sonatype.org/pages/ossrh-guide.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
  <groupId>org.openapitools</groupId>
  <artifactId>openapi-java-client</artifactId>
  <version>1.7.1</version>
  <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
  repositories {
    mavenCentral()     // Needed if the 'openapi-java-client' jar has been published to maven central.
    mavenLocal()       // Needed if the 'openapi-java-client' jar has been published to the local maven repo.
  }

  dependencies {
     implementation "org.openapitools:openapi-java-client:1.7.1"
  }
```

### Others

At first generate the JAR by executing:

```shell
mvn clean package
```

Then manually install the following JARs:

* `target/openapi-java-client-1.7.1.jar`
* `target/lib/*.jar`

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.CrawlerApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://localhost:8561");
    

    CrawlerApi apiInstance = new CrawlerApi(defaultClient);
    GetIpsAfterTimestampRequest getIpsAfterTimestampRequest = new GetIpsAfterTimestampRequest(); // GetIpsAfterTimestampRequest | Search criteria
    try {
      GetIpsAfterTimestamp200Response result = apiInstance.getIpsAfterTimestamp(getIpsAfterTimestampRequest);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling CrawlerApi#getIpsAfterTimestamp");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost:8561*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CrawlerApi* | [**getIpsAfterTimestamp**](docs/CrawlerApi.md#getIpsAfterTimestamp) | **POST** /get_ips_after_timestamp | Retrieves ip addresses of peers that have connected after a given time.
*CrawlerApi* | [**getPeerCounts**](docs/CrawlerApi.md#getPeerCounts) | **POST** /get_peer_counts | Retrieves aggregate information about peers.
*SharedApi* | [**closeConnection**](docs/SharedApi.md#closeConnection) | **POST** /close_connection | Removes a connection.
*SharedApi* | [**getConnections**](docs/SharedApi.md#getConnections) | **POST** /get_connections | Retrieve the list of connections.
*SharedApi* | [**getRoutes**](docs/SharedApi.md#getRoutes) | **POST** /get_routes | Retrieve the list of routes exposed by the service.
*SharedApi* | [**healthz**](docs/SharedApi.md#healthz) | **POST** /healthz | Heartbeat.
*SharedApi* | [**openConnection**](docs/SharedApi.md#openConnection) | **POST** /open_connection | Add a connection to another node.
*SharedApi* | [**stopNode**](docs/SharedApi.md#stopNode) | **POST** /stop_node | Stop the node.


## Documentation for Models

 - [CloseConnectionRequest](docs/CloseConnectionRequest.md)
 - [ConnectionInfo](docs/ConnectionInfo.md)
 - [GetConnections200Response](docs/GetConnections200Response.md)
 - [GetConnections200ResponseAllOf](docs/GetConnections200ResponseAllOf.md)
 - [GetIpsAfterTimestamp200Response](docs/GetIpsAfterTimestamp200Response.md)
 - [GetIpsAfterTimestamp200ResponseAllOf](docs/GetIpsAfterTimestamp200ResponseAllOf.md)
 - [GetIpsAfterTimestampRequest](docs/GetIpsAfterTimestampRequest.md)
 - [GetPeerCounts200Response](docs/GetPeerCounts200Response.md)
 - [GetPeerCounts200ResponseAllOf](docs/GetPeerCounts200ResponseAllOf.md)
 - [GetPeerCounts200ResponseAllOfPeerCounts](docs/GetPeerCounts200ResponseAllOfPeerCounts.md)
 - [GetRoutes200Response](docs/GetRoutes200Response.md)
 - [GetRoutes200ResponseAllOf](docs/GetRoutes200ResponseAllOf.md)
 - [ModelApiResponse](docs/ModelApiResponse.md)
 - [NodeType](docs/NodeType.md)
 - [OpenConnectionRequest](docs/OpenConnectionRequest.md)


## Documentation for Authorization

Authentication schemes defined for the API:
### bearerAuth

- **Type**: HTTP basic authentication


## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author

hello@chia.net

