# openapi-java-client

Chia RPC
- API version: 1.7.1
  - Build date: 2023-05-11T13:22:47.336438900-04:00[America/New_York]

The Chia node and services come with a JSON RPC API server that allows you to access information and control the services.  These are accessible via HTTPS, WebSockets, or via client SDKs. The ports can be configured in `~/.chia/mainnet/config/config.yaml`.  The RPC ports should not be exposed to the internet. TLS certificates are used to secure the communication  [using mutualTLS](https://github.com/dkackman/chia-api/wiki/Mutual-TLS).
The daemon uses port 55400 by default.

  For more information, please visit [https://www.chia.net/](https://www.chia.net/)

*Automatically generated by the [OpenAPI Generator](https://openapi-generator.tech)*


## Requirements

Building the API client library requires:
1. Java 1.8+
2. Maven (3.8.3+)/Gradle (7.2+)

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn clean install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn clean deploy
```

Refer to the [OSSRH Guide](http://central.sonatype.org/pages/ossrh-guide.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
  <groupId>org.openapitools</groupId>
  <artifactId>openapi-java-client</artifactId>
  <version>1.7.1</version>
  <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
  repositories {
    mavenCentral()     // Needed if the 'openapi-java-client' jar has been published to maven central.
    mavenLocal()       // Needed if the 'openapi-java-client' jar has been published to the local maven repo.
  }

  dependencies {
     implementation "org.openapitools:openapi-java-client:1.7.1"
  }
```

### Others

At first generate the JAR by executing:

```shell
mvn clean package
```

Then manually install the following JARs:

* `target/openapi-java-client-1.7.1.jar`
* `target/lib/*.jar`

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.DaemonApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("http://localhost");
    

    DaemonApi apiInstance = new DaemonApi(defaultClient);
    Object body = null; // Object | Empty request body
    try {
      ModelApiResponse result = apiInstance.exit(body);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling DaemonApi#exit");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DaemonApi* | [**exit**](docs/DaemonApi.md#exit) | **POST** /exit | Tells the daemon at the RPC endpoint to exit.
*DaemonApi* | [**getStatus**](docs/DaemonApi.md#getStatus) | **POST** /get_status | Indicator if the genesis block is intialized.
*DaemonApi* | [**getVersion**](docs/DaemonApi.md#getVersion) | **POST** /get_version | Get the installed version of chia at the endpoint.
*DaemonApi* | [**isRunning**](docs/DaemonApi.md#isRunning) | **POST** /is_running | Determines if the named service is running.
*DaemonApi* | [**ping**](docs/DaemonApi.md#ping) | **POST** /ping | Ping the daemon.
*DaemonApi* | [**registerService**](docs/DaemonApi.md#registerService) | **POST** /register_service | Registers this daemon to receive messages.
*DaemonApi* | [**startService**](docs/DaemonApi.md#startService) | **POST** /start_service | Starts the named service.
*DaemonApi* | [**stopService**](docs/DaemonApi.md#stopService) | **POST** /stop_service | Stops the named service.
*KeyRingApi* | [**addPrivateKey**](docs/KeyRingApi.md#addPrivateKey) | **POST** /add_private_key | Adds a private key to the keychain.
*KeyRingApi* | [**checkKeys**](docs/KeyRingApi.md#checkKeys) | **POST** /check_keys | Check the keys.
*KeyRingApi* | [**daemonDeleteAllKeys**](docs/KeyRingApi.md#daemonDeleteAllKeys) | **POST** /delete_all_keys | Deletes all keys from the keychain.
*KeyRingApi* | [**deleteKeyByFingerprint**](docs/KeyRingApi.md#deleteKeyByFingerprint) | **POST** /delete_key_by_fingerprint | Deletes all keys which have the given public key fingerprint.
*KeyRingApi* | [**getAllPrivateKeys**](docs/KeyRingApi.md#getAllPrivateKeys) | **POST** /get_all_private_keys | Returns all private keys which can be retrieved, with the given passphrases.
*KeyRingApi* | [**getFirstPrivateKey**](docs/KeyRingApi.md#getFirstPrivateKey) | **POST** /get_first_private_key | Returns the first key in the keychain.
*KeyRingApi* | [**getKeyForFingerprint**](docs/KeyRingApi.md#getKeyForFingerprint) | **POST** /get_key_for_fingerprint | Locates and returns a private key matching the provided fingerprint.
*KeyRingApi* | [**isKeyringLocked**](docs/KeyRingApi.md#isKeyringLocked) | **POST** /is_keyring_locked | Returns whether the keyring is in a locked state.
*KeyRingApi* | [**keyringStatus**](docs/KeyRingApi.md#keyringStatus) | **POST** /keyring_status | Get detailed status of the key ring.
*KeyRingApi* | [**migrateKeyring**](docs/KeyRingApi.md#migrateKeyring) | **POST** /migrate_keyring | Migrate from key phrase to key ring.
*KeyRingApi* | [**removeKeyringPassphrase**](docs/KeyRingApi.md#removeKeyringPassphrase) | **POST** /remove_keyring_passphrase | Remove the key ring passphrase.
*KeyRingApi* | [**setKeyringPassphrase**](docs/KeyRingApi.md#setKeyringPassphrase) | **POST** /set_keyring_passphrase | Update the key ring passphrase.
*KeyRingApi* | [**unlockKeyring**](docs/KeyRingApi.md#unlockKeyring) | **POST** /unlock_keyring | Unlock the keyring.
*KeyRingApi* | [**validateKeyringPassphrase**](docs/KeyRingApi.md#validateKeyringPassphrase) | **POST** /validate_keyring_passphrase | Test the validity of a passphrase.
*PlotterApi* | [**getPlotters**](docs/PlotterApi.md#getPlotters) | **POST** /get_plotters | Get info about installed and installable plotters.
*PlotterApi* | [**startPlotting**](docs/PlotterApi.md#startPlotting) | **POST** /start_plotting | Starts plotting.
*PlotterApi* | [**stopPlotting**](docs/PlotterApi.md#stopPlotting) | **POST** /stop_plotting | Stops the plot with the given id.


## Documentation for Models

 - [AddPrivateKey200Response](docs/AddPrivateKey200Response.md)
 - [AddPrivateKeyRequest](docs/AddPrivateKeyRequest.md)
 - [CheckKeysRequest](docs/CheckKeysRequest.md)
 - [DeleteKeyByFingerprintRequest](docs/DeleteKeyByFingerprintRequest.md)
 - [ErrorDetails](docs/ErrorDetails.md)
 - [ErrorDetailsErrorDetails](docs/ErrorDetailsErrorDetails.md)
 - [GetAllPrivateKeys200Response](docs/GetAllPrivateKeys200Response.md)
 - [GetAllPrivateKeys200ResponseAllOf](docs/GetAllPrivateKeys200ResponseAllOf.md)
 - [GetFirstPrivateKey200Response](docs/GetFirstPrivateKey200Response.md)
 - [GetPlotters200Response](docs/GetPlotters200Response.md)
 - [GetPlotters200ResponseAllOf](docs/GetPlotters200ResponseAllOf.md)
 - [GetStatus200Response](docs/GetStatus200Response.md)
 - [GetStatus200ResponseAllOf](docs/GetStatus200ResponseAllOf.md)
 - [GetVersion200Response](docs/GetVersion200Response.md)
 - [GetVersion200ResponseAllOf](docs/GetVersion200ResponseAllOf.md)
 - [IsKeyringLocked200Response](docs/IsKeyringLocked200Response.md)
 - [IsKeyringLocked200ResponseAllOf](docs/IsKeyringLocked200ResponseAllOf.md)
 - [IsRunning200Response](docs/IsRunning200Response.md)
 - [IsRunning200ResponseAllOf](docs/IsRunning200ResponseAllOf.md)
 - [KSize](docs/KSize.md)
 - [KeyringStatus](docs/KeyringStatus.md)
 - [KeyringStatus200Response](docs/KeyringStatus200Response.md)
 - [KeyringStatusPassphraseRequirements](docs/KeyringStatusPassphraseRequirements.md)
 - [MigrateKeyringRequest](docs/MigrateKeyringRequest.md)
 - [ModelApiResponse](docs/ModelApiResponse.md)
 - [PlotterConfig](docs/PlotterConfig.md)
 - [PlotterInfo](docs/PlotterInfo.md)
 - [PrivateKey](docs/PrivateKey.md)
 - [QueuedPlotInfo](docs/QueuedPlotInfo.md)
 - [RegisterService200Response](docs/RegisterService200Response.md)
 - [RegisterService200ResponseAllOf](docs/RegisterService200ResponseAllOf.md)
 - [RegisterServiceRequest](docs/RegisterServiceRequest.md)
 - [RemoveKeyringPassphraseRequest](docs/RemoveKeyringPassphraseRequest.md)
 - [SetKeyringPassphraseRequest](docs/SetKeyringPassphraseRequest.md)
 - [StartPlotting200Response](docs/StartPlotting200Response.md)
 - [StartPlotting200ResponseAllOf](docs/StartPlotting200ResponseAllOf.md)
 - [StopPlottingRequest](docs/StopPlottingRequest.md)
 - [UnlockKeyringRequest](docs/UnlockKeyringRequest.md)


## Documentation for Authorization

Authentication schemes defined for the API:
### bearerAuth

- **Type**: HTTP basic authentication


## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author

hello@chia.net

