# openapi-java-client

Chia RPC
- API version: 1.7.1
  - Build date: 2023-05-11T12:59:57.894897700-04:00[America/New_York]

The Chia node and services come with a JSON RPC API server that allows you to access information and control the services.  These are accessible via HTTPS, WebSockets, or via client SDKs. The ports can be configured in `~/.chia/mainnet/config/config.yaml`.  The RPC ports should not be exposed to the internet. TLS certificates are used to secure the communication  [using mutualTLS](https://github.com/dkackman/chia-api/wiki/Mutual-TLS).
The data layer uses port 8561 by default.

  For more information, please visit [https://www.chia.net/](https://www.chia.net/)

*Automatically generated by the [OpenAPI Generator](https://openapi-generator.tech)*


## Requirements

Building the API client library requires:
1. Java 1.8+
2. Maven (3.8.3+)/Gradle (7.2+)

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn clean install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn clean deploy
```

Refer to the [OSSRH Guide](http://central.sonatype.org/pages/ossrh-guide.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
  <groupId>org.openapitools</groupId>
  <artifactId>openapi-java-client</artifactId>
  <version>1.7.1</version>
  <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
  repositories {
    mavenCentral()     // Needed if the 'openapi-java-client' jar has been published to maven central.
    mavenLocal()       // Needed if the 'openapi-java-client' jar has been published to the local maven repo.
  }

  dependencies {
     implementation "org.openapitools:openapi-java-client:1.7.1"
  }
```

### Others

At first generate the JAR by executing:

```shell
mvn clean package
```

Then manually install the following JARs:

* `target/openapi-java-client-1.7.1.jar`
* `target/lib/*.jar`

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.DataLayerApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://localhost:8561");
    

    DataLayerApi apiInstance = new DataLayerApi(defaultClient);
    AddMissingFilesRequest addMissingFilesRequest = new AddMissingFilesRequest(); // AddMissingFilesRequest | 
    try {
      ModelApiResponse result = apiInstance.addMissingFiles(addMissingFilesRequest);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling DataLayerApi#addMissingFiles");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost:8561*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DataLayerApi* | [**addMissingFiles**](docs/DataLayerApi.md#addMissingFiles) | **POST** /add_missing_files | Complete the data server files.
*DataLayerApi* | [**batchUpdate**](docs/DataLayerApi.md#batchUpdate) | **POST** /batch_update | Applies a batch of updates.
*DataLayerApi* | [**createDataStore**](docs/DataLayerApi.md#createDataStore) | **POST** /create_data_store | Creates a data store.
*DataLayerApi* | [**deleteKey**](docs/DataLayerApi.md#deleteKey) | **POST** /delete_key | Removes a list of rows.
*DataLayerApi* | [**getAncestors**](docs/DataLayerApi.md#getAncestors) | **POST** /get_ancestors | Gets the list of ancestors for a given id/hash pair.
*DataLayerApi* | [**getKeys**](docs/DataLayerApi.md#getKeys) | **POST** /get_keys | Get the keys for a given id/root_hash pair.
*DataLayerApi* | [**getKeysValues**](docs/DataLayerApi.md#getKeysValues) | **POST** /get_keys_values | Get the keys and values for a given id/root_hash pair.
*DataLayerApi* | [**getKvDiff**](docs/DataLayerApi.md#getKvDiff) | **POST** /get_kv_diff | Get kv diff between two root hashes.
*DataLayerApi* | [**getLocalRoot**](docs/DataLayerApi.md#getLocalRoot) | **POST** /get_local_root | Gets hash of latest tree root saved in our local datastore.
*DataLayerApi* | [**getOwnedStores**](docs/DataLayerApi.md#getOwnedStores) | **POST** /get_owned_stores | Gets the list of owned store ids.
*DataLayerApi* | [**getRoot**](docs/DataLayerApi.md#getRoot) | **POST** /get_root | Gets hash of latest tree root.
*DataLayerApi* | [**getRootHistory**](docs/DataLayerApi.md#getRootHistory) | **POST** /get_root_history | Get history of state hashes for a store.
*DataLayerApi* | [**getRoots**](docs/DataLayerApi.md#getRoots) | **POST** /get_roots | Gets state hashes for a list of roots
*DataLayerApi* | [**getSyncStatus**](docs/DataLayerApi.md#getSyncStatus) | **POST** /get_sync_status | Gets the sync status of a store.
*DataLayerApi* | [**getValue**](docs/DataLayerApi.md#getValue) | **POST** /get_value | Get the value for a given id/key pair.
*DataLayerApi* | [**insert**](docs/DataLayerApi.md#insert) | **POST** /insert | Adds a list of clvm objects as bytes to add to table.
*MirrorsApi* | [**addMirror**](docs/MirrorsApi.md#addMirror) | **POST** /add_mirror | Adds a mirror.
*MirrorsApi* | [**deleteMirror**](docs/MirrorsApi.md#deleteMirror) | **POST** /delete_mirror | Deletes a mirror.
*MirrorsApi* | [**getMirrors**](docs/MirrorsApi.md#getMirrors) | **POST** /get_mirrors | Gets the mirrors for a given store id.
*OffersApi* | [**cancelOffer**](docs/OffersApi.md#cancelOffer) | **POST** /cancel_offer | Cancels an offer.
*OffersApi* | [**makeOffer**](docs/OffersApi.md#makeOffer) | **POST** /make_offer | Makes an offer.
*OffersApi* | [**takeOffer**](docs/OffersApi.md#takeOffer) | **POST** /take_offer | Takes an offer.
*OffersApi* | [**verifyOffer**](docs/OffersApi.md#verifyOffer) | **POST** /verify_offer | Verifies an offer.
*SharedApi* | [**closeConnection**](docs/SharedApi.md#closeConnection) | **POST** /close_connection | Removes a connection.
*SharedApi* | [**getConnections**](docs/SharedApi.md#getConnections) | **POST** /get_connections | Retrieve the list of connections.
*SharedApi* | [**getRoutes**](docs/SharedApi.md#getRoutes) | **POST** /get_routes | Retrieve the list of routes exposed by the service.
*SharedApi* | [**healthz**](docs/SharedApi.md#healthz) | **POST** /healthz | Heartbeat.
*SharedApi* | [**openConnection**](docs/SharedApi.md#openConnection) | **POST** /open_connection | Add a connection to another node.
*SharedApi* | [**stopNode**](docs/SharedApi.md#stopNode) | **POST** /stop_node | Stop the node.
*SubscriptionsApi* | [**removeSubscriptions**](docs/SubscriptionsApi.md#removeSubscriptions) | **POST** /remove_subscriptions | Removes subscriptions for the given id.
*SubscriptionsApi* | [**subscribe**](docs/SubscriptionsApi.md#subscribe) | **POST** /subscribe | Subscribe to singleton.
*SubscriptionsApi* | [**subscriptions**](docs/SubscriptionsApi.md#subscriptions) | **POST** /subscriptions | List current subscriptions.
*SubscriptionsApi* | [**unsubscribe**](docs/SubscriptionsApi.md#unsubscribe) | **POST** /unsubscribe | Unsubscribe from singleton.


## Documentation for Models

 - [AddMirrorRequest](docs/AddMirrorRequest.md)
 - [AddMissingFilesRequest](docs/AddMissingFilesRequest.md)
 - [BatchUpdate200Response](docs/BatchUpdate200Response.md)
 - [BatchUpdate200ResponseAllOf](docs/BatchUpdate200ResponseAllOf.md)
 - [BatchUpdateRequest](docs/BatchUpdateRequest.md)
 - [CancelOfferRequest](docs/CancelOfferRequest.md)
 - [CancelOfferRequestOffer](docs/CancelOfferRequestOffer.md)
 - [CloseConnectionRequest](docs/CloseConnectionRequest.md)
 - [Coin](docs/Coin.md)
 - [CoinSpend](docs/CoinSpend.md)
 - [ConnectionInfo](docs/ConnectionInfo.md)
 - [CreateDataStore200Response](docs/CreateDataStore200Response.md)
 - [CreateDataStore200ResponseAllOf](docs/CreateDataStore200ResponseAllOf.md)
 - [CreateDataStoreRequest](docs/CreateDataStoreRequest.md)
 - [DeleteKeyRequest](docs/DeleteKeyRequest.md)
 - [DeleteMirrorRequest](docs/DeleteMirrorRequest.md)
 - [GetAncestors200Response](docs/GetAncestors200Response.md)
 - [GetAncestors200ResponseAllOf](docs/GetAncestors200ResponseAllOf.md)
 - [GetAncestorsRequest](docs/GetAncestorsRequest.md)
 - [GetConnections200Response](docs/GetConnections200Response.md)
 - [GetConnections200ResponseAllOf](docs/GetConnections200ResponseAllOf.md)
 - [GetKeys200Response](docs/GetKeys200Response.md)
 - [GetKeys200ResponseAllOf](docs/GetKeys200ResponseAllOf.md)
 - [GetKeysRequest](docs/GetKeysRequest.md)
 - [GetKeysValues200Response](docs/GetKeysValues200Response.md)
 - [GetKeysValues200ResponseAllOf](docs/GetKeysValues200ResponseAllOf.md)
 - [GetKvDiff200Response](docs/GetKvDiff200Response.md)
 - [GetKvDiff200ResponseAllOf](docs/GetKvDiff200ResponseAllOf.md)
 - [GetKvDiff200ResponseAllOfDiffInner](docs/GetKvDiff200ResponseAllOfDiffInner.md)
 - [GetKvDiffRequest](docs/GetKvDiffRequest.md)
 - [GetLocalRoot200Response](docs/GetLocalRoot200Response.md)
 - [GetLocalRoot200ResponseAllOf](docs/GetLocalRoot200ResponseAllOf.md)
 - [GetMirrors200Response](docs/GetMirrors200Response.md)
 - [GetMirrors200ResponseAllOf](docs/GetMirrors200ResponseAllOf.md)
 - [GetOwnedStores200Response](docs/GetOwnedStores200Response.md)
 - [GetOwnedStores200ResponseAllOf](docs/GetOwnedStores200ResponseAllOf.md)
 - [GetRoot200Response](docs/GetRoot200Response.md)
 - [GetRoot200ResponseAllOf](docs/GetRoot200ResponseAllOf.md)
 - [GetRootHistory200Response](docs/GetRootHistory200Response.md)
 - [GetRootHistory200ResponseAllOf](docs/GetRootHistory200ResponseAllOf.md)
 - [GetRootHistory200ResponseAllOfRootHistoryInner](docs/GetRootHistory200ResponseAllOfRootHistoryInner.md)
 - [GetRoots200Response](docs/GetRoots200Response.md)
 - [GetRoots200ResponseAllOf](docs/GetRoots200ResponseAllOf.md)
 - [GetRoots200ResponseAllOfRootHashesInner](docs/GetRoots200ResponseAllOfRootHashesInner.md)
 - [GetRootsRequest](docs/GetRootsRequest.md)
 - [GetRoutes200Response](docs/GetRoutes200Response.md)
 - [GetRoutes200ResponseAllOf](docs/GetRoutes200ResponseAllOf.md)
 - [GetSyncStatus200Response](docs/GetSyncStatus200Response.md)
 - [GetSyncStatus200ResponseAllOf](docs/GetSyncStatus200ResponseAllOf.md)
 - [GetSyncStatus200ResponseAllOfSyncStatus](docs/GetSyncStatus200ResponseAllOfSyncStatus.md)
 - [GetSyncStatusRequest](docs/GetSyncStatusRequest.md)
 - [GetValue200Response](docs/GetValue200Response.md)
 - [GetValue200ResponseAllOf](docs/GetValue200ResponseAllOf.md)
 - [GetValueRequest](docs/GetValueRequest.md)
 - [InsertRequest](docs/InsertRequest.md)
 - [InternalNode](docs/InternalNode.md)
 - [KeyValue](docs/KeyValue.md)
 - [Layer](docs/Layer.md)
 - [MakeOffer200Response](docs/MakeOffer200Response.md)
 - [MakeOffer200ResponseAllOf](docs/MakeOffer200ResponseAllOf.md)
 - [MakeOfferRequest](docs/MakeOfferRequest.md)
 - [Mirror](docs/Mirror.md)
 - [ModelApiResponse](docs/ModelApiResponse.md)
 - [NodeType](docs/NodeType.md)
 - [Offer](docs/Offer.md)
 - [OfferStore](docs/OfferStore.md)
 - [OpenConnectionRequest](docs/OpenConnectionRequest.md)
 - [Proof](docs/Proof.md)
 - [SpendBundle](docs/SpendBundle.md)
 - [StoreProofs](docs/StoreProofs.md)
 - [SubscribeRequest](docs/SubscribeRequest.md)
 - [TakeOffer200Response](docs/TakeOffer200Response.md)
 - [TakeOffer200ResponseAllOf](docs/TakeOffer200ResponseAllOf.md)
 - [TakeOfferRequest](docs/TakeOfferRequest.md)
 - [TerminalNode](docs/TerminalNode.md)
 - [TransactionRecord](docs/TransactionRecord.md)
 - [TransactionType](docs/TransactionType.md)
 - [VerifyOffer200Response](docs/VerifyOffer200Response.md)
 - [VerifyOffer200ResponseAllOf](docs/VerifyOffer200ResponseAllOf.md)


## Documentation for Authorization

Authentication schemes defined for the API:
### bearerAuth

- **Type**: HTTP basic authentication


## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author

hello@chia.net

