# openapi-java-client

Chia RPC
- API version: 1.7.1
  - Build date: 2023-05-11T13:14:33.026379300-04:00[America/New_York]

The Chia node and services come with a JSON RPC API server that allows you to access information and control the services.  These are accessible via HTTPS, WebSockets, or via client SDKs. The ports can be configured in `~/.chia/mainnet/config/config.yaml`.  The RPC ports should not be exposed to the internet. TLS certificates are used to secure the communication  [using mutualTLS](https://github.com/dkackman/chia-api/wiki/Mutual-TLS).
The farmer uses port 8559 by default.

  For more information, please visit [https://www.chia.net/](https://www.chia.net/)

*Automatically generated by the [OpenAPI Generator](https://openapi-generator.tech)*


## Requirements

Building the API client library requires:
1. Java 1.8+
2. Maven (3.8.3+)/Gradle (7.2+)

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn clean install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn clean deploy
```

Refer to the [OSSRH Guide](http://central.sonatype.org/pages/ossrh-guide.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
  <groupId>org.openapitools</groupId>
  <artifactId>openapi-java-client</artifactId>
  <version>1.7.1</version>
  <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
  repositories {
    mavenCentral()     // Needed if the 'openapi-java-client' jar has been published to maven central.
    mavenLocal()       // Needed if the 'openapi-java-client' jar has been published to the local maven repo.
  }

  dependencies {
     implementation "org.openapitools:openapi-java-client:1.7.1"
  }
```

### Others

At first generate the JAR by executing:

```shell
mvn clean package
```

Then manually install the following JARs:

* `target/openapi-java-client-1.7.1.jar`
* `target/lib/*.jar`

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.FarmerApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://localhost:8559");
    

    FarmerApi apiInstance = new FarmerApi(defaultClient);
    PlotPathRequestData plotPathRequestData = new PlotPathRequestData(); // PlotPathRequestData | Search filter parameters
    try {
      GetHarvesterPlotsValid200Response result = apiInstance.getHarvesterPlotsDuplicates(plotPathRequestData);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling FarmerApi#getHarvesterPlotsDuplicates");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost:8559*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*FarmerApi* | [**getHarvesterPlotsDuplicates**](docs/FarmerApi.md#getHarvesterPlotsDuplicates) | **POST** /get_harvester_plots_duplicates | Get a paginated list of duplicate plots.
*FarmerApi* | [**getHarvesterPlotsInvalid**](docs/FarmerApi.md#getHarvesterPlotsInvalid) | **POST** /get_harvester_plots_invalid | Get a paginated list of invalid plots.
*FarmerApi* | [**getHarvesterPlotsKeysMissing**](docs/FarmerApi.md#getHarvesterPlotsKeysMissing) | **POST** /get_harvester_plots_keys_missing | Get a paginated list of plots with missing keys.
*FarmerApi* | [**getHarvesterPlotsValid**](docs/FarmerApi.md#getHarvesterPlotsValid) | **POST** /get_harvester_plots_valid | Get a paginated list of valid plots.
*FarmerApi* | [**getHarvesters**](docs/FarmerApi.md#getHarvesters) | **POST** /get_harvesters | Get the list of harvesters.
*FarmerApi* | [**getHarvestersSummary**](docs/FarmerApi.md#getHarvestersSummary) | **POST** /get_harvesters_summary | Get a summary of harvesters.
*FarmerApi* | [**getPoolLoginLink**](docs/FarmerApi.md#getPoolLoginLink) | **POST** /get_pool_login_link | Get&#39;s the pool login link, if any.
*FarmerApi* | [**getPoolState**](docs/FarmerApi.md#getPoolState) | **POST** /get_pool_state | Get&#39;s the state of the pool.
*FarmerApi* | [**getRewardTargets**](docs/FarmerApi.md#getRewardTargets) | **POST** /get_reward_targets | Get the farm and pool reward targets.
*FarmerApi* | [**getSignagePoint**](docs/FarmerApi.md#getSignagePoint) | **POST** /get_signage_point | Get&#39;s a signage point by hash.
*FarmerApi* | [**getSignagePoints**](docs/FarmerApi.md#getSignagePoints) | **POST** /get_signage_points | Get signage points.
*FarmerApi* | [**setPayoutInstructions**](docs/FarmerApi.md#setPayoutInstructions) | **POST** /set_payout_instructions | Set&#39;s a pool&#39;s payout instructions.
*FarmerApi* | [**setRewardTargets**](docs/FarmerApi.md#setRewardTargets) | **POST** /set_reward_targets | Set the farm and pool reward targets.
*SharedApi* | [**closeConnection**](docs/SharedApi.md#closeConnection) | **POST** /close_connection | Removes a connection.
*SharedApi* | [**getConnections**](docs/SharedApi.md#getConnections) | **POST** /get_connections | Retrieve the list of connections.
*SharedApi* | [**getRoutes**](docs/SharedApi.md#getRoutes) | **POST** /get_routes | Retrieve the list of routes exposed by the service.
*SharedApi* | [**healthz**](docs/SharedApi.md#healthz) | **POST** /healthz | Heartbeat.
*SharedApi* | [**openConnection**](docs/SharedApi.md#openConnection) | **POST** /open_connection | Add a connection to another node.
*SharedApi* | [**stopNode**](docs/SharedApi.md#stopNode) | **POST** /stop_node | Stop the node.


## Documentation for Models

 - [CloseConnectionRequest](docs/CloseConnectionRequest.md)
 - [ConnectionInfo](docs/ConnectionInfo.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [FarmerSignagePoint](docs/FarmerSignagePoint.md)
 - [FilterItem](docs/FilterItem.md)
 - [GetConnections200Response](docs/GetConnections200Response.md)
 - [GetConnections200ResponseAllOf](docs/GetConnections200ResponseAllOf.md)
 - [GetHarvesterPlotsValid200Response](docs/GetHarvesterPlotsValid200Response.md)
 - [GetHarvesters200Response](docs/GetHarvesters200Response.md)
 - [GetHarvesters200ResponseAllOf](docs/GetHarvesters200ResponseAllOf.md)
 - [GetHarvestersSummary200Response](docs/GetHarvestersSummary200Response.md)
 - [GetHarvestersSummary200ResponseAllOf](docs/GetHarvestersSummary200ResponseAllOf.md)
 - [GetPoolLoginLink200Response](docs/GetPoolLoginLink200Response.md)
 - [GetPoolLoginLink200ResponseAllOf](docs/GetPoolLoginLink200ResponseAllOf.md)
 - [GetPoolLoginLinkRequest](docs/GetPoolLoginLinkRequest.md)
 - [GetPoolState200Response](docs/GetPoolState200Response.md)
 - [GetPoolState200ResponseAllOf](docs/GetPoolState200ResponseAllOf.md)
 - [GetRewardTargets200Response](docs/GetRewardTargets200Response.md)
 - [GetRewardTargets200ResponseAllOf](docs/GetRewardTargets200ResponseAllOf.md)
 - [GetRewardTargetsRequest](docs/GetRewardTargetsRequest.md)
 - [GetRoutes200Response](docs/GetRoutes200Response.md)
 - [GetRoutes200ResponseAllOf](docs/GetRoutes200ResponseAllOf.md)
 - [GetSignagePoint200Response](docs/GetSignagePoint200Response.md)
 - [GetSignagePointRequest](docs/GetSignagePointRequest.md)
 - [GetSignagePoints200Response](docs/GetSignagePoints200Response.md)
 - [GetSignagePoints200ResponseAllOf](docs/GetSignagePoints200ResponseAllOf.md)
 - [HarvesterConnection](docs/HarvesterConnection.md)
 - [HarvesterInfo](docs/HarvesterInfo.md)
 - [HarvesterInfoSyncing](docs/HarvesterInfoSyncing.md)
 - [HarvesterSummary](docs/HarvesterSummary.md)
 - [KSize](docs/KSize.md)
 - [ModelApiResponse](docs/ModelApiResponse.md)
 - [NodeType](docs/NodeType.md)
 - [OpenConnectionRequest](docs/OpenConnectionRequest.md)
 - [PaginatedPlotRequest](docs/PaginatedPlotRequest.md)
 - [PlotInfo](docs/PlotInfo.md)
 - [PlotInfoRequestData](docs/PlotInfoRequestData.md)
 - [PlotPathRequestData](docs/PlotPathRequestData.md)
 - [PoolPoint](docs/PoolPoint.md)
 - [PoolStateInfo](docs/PoolStateInfo.md)
 - [PoolWalletConfig](docs/PoolWalletConfig.md)
 - [ProofOfSpace](docs/ProofOfSpace.md)
 - [SetPayoutInstructionsRequest](docs/SetPayoutInstructionsRequest.md)
 - [SetRewardTargetsRequest](docs/SetRewardTargetsRequest.md)
 - [SignagePointBundle](docs/SignagePointBundle.md)


## Documentation for Authorization

Authentication schemes defined for the API:
### bearerAuth

- **Type**: HTTP basic authentication


## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author

hello@chia.net

