# openapi-java-client

Chia RPC
- API version: 1.7.1
  - Build date: 2023-05-11T13:05:15.064688400-04:00[America/New_York]

The Chia node and services come with a JSON RPC API server that allows you to access information and control the services.  These are accessible via HTTPS, WebSockets, or via client SDKs. The ports can be configured in `~/.chia/mainnet/config/config.yaml`.  The RPC ports should not be exposed to the internet. TLS certificates are used to secure the communication  [using mutualTLS](https://github.com/dkackman/chia-api/wiki/Mutual-TLS).
The full node uses port 8555 by default.

  For more information, please visit [https://www.chia.net/](https://www.chia.net/)

*Automatically generated by the [OpenAPI Generator](https://openapi-generator.tech)*


## Requirements

Building the API client library requires:
1. Java 1.8+
2. Maven (3.8.3+)/Gradle (7.2+)

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn clean install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn clean deploy
```

Refer to the [OSSRH Guide](http://central.sonatype.org/pages/ossrh-guide.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
  <groupId>org.openapitools</groupId>
  <artifactId>openapi-java-client</artifactId>
  <version>1.7.1</version>
  <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
  repositories {
    mavenCentral()     // Needed if the 'openapi-java-client' jar has been published to maven central.
    mavenLocal()       // Needed if the 'openapi-java-client' jar has been published to the local maven repo.
  }

  dependencies {
     implementation "org.openapitools:openapi-java-client:1.7.1"
  }
```

### Others

At first generate the JAR by executing:

```shell
mvn clean package
```

Then manually install the following JARs:

* `target/openapi-java-client-1.7.1.jar`
* `target/lib/*.jar`

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.BlocksApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://localhost:8555");
    

    BlocksApi apiInstance = new BlocksApi(defaultClient);
    GetBlockRecordRequest getBlockRecordRequest = new GetBlockRecordRequest(); // GetBlockRecordRequest | the block's header_hash
    try {
      GetAdditionsAndRemovals200Response result = apiInstance.getAdditionsAndRemovals(getBlockRecordRequest);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling BlocksApi#getAdditionsAndRemovals");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost:8555*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BlocksApi* | [**getAdditionsAndRemovals**](docs/BlocksApi.md#getAdditionsAndRemovals) | **POST** /get_additions_and_removals | Retrieves the additions and removals for a certain block.
*BlocksApi* | [**getBlock**](docs/BlocksApi.md#getBlock) | **POST** /get_block | Retrieves a block by header hash.
*BlocksApi* | [**getBlockCountMetrics**](docs/BlocksApi.md#getBlockCountMetrics) | **POST** /get_block_count_metrics | Retrieves aggregate information about blocks.
*BlocksApi* | [**getBlockRecord**](docs/BlocksApi.md#getBlockRecord) | **POST** /get_block_record | Retrieves a block record by header hash.
*BlocksApi* | [**getBlockRecordByHeight**](docs/BlocksApi.md#getBlockRecordByHeight) | **POST** /get_block_record_by_height | Retrieves a block record by height.
*BlocksApi* | [**getBlockRecords**](docs/BlocksApi.md#getBlockRecords) | **POST** /get_block_records | Retrieves block records in a range.
*BlocksApi* | [**getBlockSpends**](docs/BlocksApi.md#getBlockSpends) | **POST** /get_block_spends | Retrieves the spends in the given block.
*BlocksApi* | [**getBlocks**](docs/BlocksApi.md#getBlocks) | **POST** /get_blocks | Get the blocks between a start and end height.
*BlocksApi* | [**getRecentSignagePointOrEos**](docs/BlocksApi.md#getRecentSignagePointOrEos) | **POST** /get_recent_signage_point_or_eos | Retrieves a recent signage point or end of slot.
*BlocksApi* | [**getUnfinishedBlockHeaders**](docs/BlocksApi.md#getUnfinishedBlockHeaders) | **POST** /get_unfinished_block_headers | Retrieves unfinished block headers.
*CoinsApi* | [**getCoinRecordByName**](docs/CoinsApi.md#getCoinRecordByName) | **POST** /get_coin_record_by_name | Retrieves a coin record by it&#39;s name.
*CoinsApi* | [**getCoinRecordsByHint**](docs/CoinsApi.md#getCoinRecordsByHint) | **POST** /get_coin_records_by_hint | Retrieves coins by hint.
*CoinsApi* | [**getCoinRecordsByNames**](docs/CoinsApi.md#getCoinRecordsByNames) | **POST** /get_coin_records_by_names | Retrieves the coins for given coin IDs.
*CoinsApi* | [**getCoinRecordsByParentIds**](docs/CoinsApi.md#getCoinRecordsByParentIds) | **POST** /get_coin_records_by_parent_ids | Retrieves the coins for given parent coin IDs.
*CoinsApi* | [**getCoinRecordsByPuzzleHash**](docs/CoinsApi.md#getCoinRecordsByPuzzleHash) | **POST** /get_coin_records_by_puzzle_hash | Retrieves the coins for a given puzzlehash.
*CoinsApi* | [**getCoinRecordsByPuzzleHashes**](docs/CoinsApi.md#getCoinRecordsByPuzzleHashes) | **POST** /get_coin_records_by_puzzle_hashes | Retrieves the coins for a given puzzlehashes
*CoinsApi* | [**getPuzzleAndSolution**](docs/CoinsApi.md#getPuzzleAndSolution) | **POST** /get_puzzle_and_solution | Retrieves a coin solution.
*CoinsApi* | [**pushTx**](docs/CoinsApi.md#pushTx) | **POST** /push_tx | Pushes a transaction/spend bundle to the mempool and blockchain.
*FeesApi* | [**getFeeEstimate**](docs/FeesApi.md#getFeeEstimate) | **POST** /get_fee_estimate | Estimates the fee for a given spend_bundle.
*FullNodeApi* | [**fullNodeGetNetworkInfo**](docs/FullNodeApi.md#fullNodeGetNetworkInfo) | **POST** /get_network_info | Retrieves some information about the current network.
*FullNodeApi* | [**getBlockchainState**](docs/FullNodeApi.md#getBlockchainState) | **POST** /get_blockchain_state | Retrieves a summary of the current state of the blockchain and full node.
*FullNodeApi* | [**getNetworkSpace**](docs/FullNodeApi.md#getNetworkSpace) | **POST** /get_network_space | Retrieves an estimate of total space.
*MempoolApi* | [**getAllMempoolItems**](docs/MempoolApi.md#getAllMempoolItems) | **POST** /get_all_mempool_items | Returns all items in the mempool.
*MempoolApi* | [**getAllMempoolTxIds**](docs/MempoolApi.md#getAllMempoolTxIds) | **POST** /get_all_mempool_tx_ids | Returns a list of all transaction IDs in the mempool.
*MempoolApi* | [**getMempoolItemByTxId**](docs/MempoolApi.md#getMempoolItemByTxId) | **POST** /get_mempool_item_by_tx_id | Returns a specific item from the mempool.
*SharedApi* | [**closeConnection**](docs/SharedApi.md#closeConnection) | **POST** /close_connection | Removes a connection.
*SharedApi* | [**getConnections**](docs/SharedApi.md#getConnections) | **POST** /get_connections | Retrieve the list of connections.
*SharedApi* | [**getRoutes**](docs/SharedApi.md#getRoutes) | **POST** /get_routes | Retrieve the list of routes exposed by the service.
*SharedApi* | [**healthz**](docs/SharedApi.md#healthz) | **POST** /healthz | Heartbeat.
*SharedApi* | [**openConnection**](docs/SharedApi.md#openConnection) | **POST** /open_connection | Add a connection to another node.
*SharedApi* | [**stopNode**](docs/SharedApi.md#stopNode) | **POST** /stop_node | Stop the node.


## Documentation for Models

 - [BlockRecord](docs/BlockRecord.md)
 - [BlockRecordChallengeVdfOutput](docs/BlockRecordChallengeVdfOutput.md)
 - [BlockchainState](docs/BlockchainState.md)
 - [BlockchainStateMempoolMinFees](docs/BlockchainStateMempoolMinFees.md)
 - [BlockchainStateSync](docs/BlockchainStateSync.md)
 - [ChallengeChainSubSlot](docs/ChallengeChainSubSlot.md)
 - [ClassgroupElement](docs/ClassgroupElement.md)
 - [CloseConnectionRequest](docs/CloseConnectionRequest.md)
 - [Coin](docs/Coin.md)
 - [CoinRecord](docs/CoinRecord.md)
 - [CoinSearchOptions](docs/CoinSearchOptions.md)
 - [CoinSpend](docs/CoinSpend.md)
 - [Condition](docs/Condition.md)
 - [ConditionWithArgs](docs/ConditionWithArgs.md)
 - [ConnectionInfo](docs/ConnectionInfo.md)
 - [EndOfSubSlotBundle](docs/EndOfSubSlotBundle.md)
 - [Foliage](docs/Foliage.md)
 - [FoliageBlockData](docs/FoliageBlockData.md)
 - [FoliageTransactionBlock](docs/FoliageTransactionBlock.md)
 - [FullBlock](docs/FullBlock.md)
 - [FullNodeGetNetworkInfo200Response](docs/FullNodeGetNetworkInfo200Response.md)
 - [GetAdditionsAndRemovals200Response](docs/GetAdditionsAndRemovals200Response.md)
 - [GetAdditionsAndRemovals200ResponseAllOf](docs/GetAdditionsAndRemovals200ResponseAllOf.md)
 - [GetAllMempoolItems200Response](docs/GetAllMempoolItems200Response.md)
 - [GetAllMempoolItems200ResponseAllOf](docs/GetAllMempoolItems200ResponseAllOf.md)
 - [GetAllMempoolTxIds200Response](docs/GetAllMempoolTxIds200Response.md)
 - [GetAllMempoolTxIds200ResponseAllOf](docs/GetAllMempoolTxIds200ResponseAllOf.md)
 - [GetBlock200Response](docs/GetBlock200Response.md)
 - [GetBlock200ResponseAllOf](docs/GetBlock200ResponseAllOf.md)
 - [GetBlockCountMetrics200Response](docs/GetBlockCountMetrics200Response.md)
 - [GetBlockCountMetrics200ResponseAllOf](docs/GetBlockCountMetrics200ResponseAllOf.md)
 - [GetBlockCountMetrics200ResponseAllOfMetrics](docs/GetBlockCountMetrics200ResponseAllOfMetrics.md)
 - [GetBlockRecord200Response](docs/GetBlockRecord200Response.md)
 - [GetBlockRecord200ResponseAllOf](docs/GetBlockRecord200ResponseAllOf.md)
 - [GetBlockRecordByHeightRequest](docs/GetBlockRecordByHeightRequest.md)
 - [GetBlockRecordRequest](docs/GetBlockRecordRequest.md)
 - [GetBlockRecords200Response](docs/GetBlockRecords200Response.md)
 - [GetBlockRecords200ResponseAllOf](docs/GetBlockRecords200ResponseAllOf.md)
 - [GetBlockRecordsRequest](docs/GetBlockRecordsRequest.md)
 - [GetBlockSpends200Response](docs/GetBlockSpends200Response.md)
 - [GetBlockSpends200ResponseAllOf](docs/GetBlockSpends200ResponseAllOf.md)
 - [GetBlockchainState200Response](docs/GetBlockchainState200Response.md)
 - [GetBlockchainState200ResponseAllOf](docs/GetBlockchainState200ResponseAllOf.md)
 - [GetBlocks200Response](docs/GetBlocks200Response.md)
 - [GetBlocks200ResponseAllOf](docs/GetBlocks200ResponseAllOf.md)
 - [GetBlocksRequest](docs/GetBlocksRequest.md)
 - [GetCoinRecordByName200Response](docs/GetCoinRecordByName200Response.md)
 - [GetCoinRecordByName200ResponseAllOf](docs/GetCoinRecordByName200ResponseAllOf.md)
 - [GetCoinRecordByNameRequest](docs/GetCoinRecordByNameRequest.md)
 - [GetCoinRecordsByHintRequest](docs/GetCoinRecordsByHintRequest.md)
 - [GetCoinRecordsByHintRequestAllOf](docs/GetCoinRecordsByHintRequestAllOf.md)
 - [GetCoinRecordsByNamesRequest](docs/GetCoinRecordsByNamesRequest.md)
 - [GetCoinRecordsByNamesRequestAllOf](docs/GetCoinRecordsByNamesRequestAllOf.md)
 - [GetCoinRecordsByParentIdsRequest](docs/GetCoinRecordsByParentIdsRequest.md)
 - [GetCoinRecordsByParentIdsRequestAllOf](docs/GetCoinRecordsByParentIdsRequestAllOf.md)
 - [GetCoinRecordsByPuzzleHash200Response](docs/GetCoinRecordsByPuzzleHash200Response.md)
 - [GetCoinRecordsByPuzzleHashRequest](docs/GetCoinRecordsByPuzzleHashRequest.md)
 - [GetCoinRecordsByPuzzleHashRequestAllOf](docs/GetCoinRecordsByPuzzleHashRequestAllOf.md)
 - [GetCoinRecordsByPuzzleHashesRequest](docs/GetCoinRecordsByPuzzleHashesRequest.md)
 - [GetCoinRecordsByPuzzleHashesRequestAllOf](docs/GetCoinRecordsByPuzzleHashesRequestAllOf.md)
 - [GetConnections200Response](docs/GetConnections200Response.md)
 - [GetConnections200ResponseAllOf](docs/GetConnections200ResponseAllOf.md)
 - [GetFeeEstimate200Response](docs/GetFeeEstimate200Response.md)
 - [GetFeeEstimate200ResponseAllOf](docs/GetFeeEstimate200ResponseAllOf.md)
 - [GetFeeEstimateRequest](docs/GetFeeEstimateRequest.md)
 - [GetMempoolItemByTxId200Response](docs/GetMempoolItemByTxId200Response.md)
 - [GetMempoolItemByTxId200ResponseAllOf](docs/GetMempoolItemByTxId200ResponseAllOf.md)
 - [GetMempoolItemByTxIdRequest](docs/GetMempoolItemByTxIdRequest.md)
 - [GetNetworkSpace200Response](docs/GetNetworkSpace200Response.md)
 - [GetNetworkSpace200ResponseAllOf](docs/GetNetworkSpace200ResponseAllOf.md)
 - [GetNetworkSpaceRequest](docs/GetNetworkSpaceRequest.md)
 - [GetPuzzleAndSolution200Response](docs/GetPuzzleAndSolution200Response.md)
 - [GetPuzzleAndSolution200ResponseAllOf](docs/GetPuzzleAndSolution200ResponseAllOf.md)
 - [GetPuzzleAndSolutionRequest](docs/GetPuzzleAndSolutionRequest.md)
 - [GetRecentSignagePointOrEos200Response](docs/GetRecentSignagePointOrEos200Response.md)
 - [GetRecentSignagePointOrEos200ResponseAllOf](docs/GetRecentSignagePointOrEos200ResponseAllOf.md)
 - [GetRecentSignagePointOrEos200ResponseOneOf](docs/GetRecentSignagePointOrEos200ResponseOneOf.md)
 - [GetRecentSignagePointOrEos200ResponseOneOf1](docs/GetRecentSignagePointOrEos200ResponseOneOf1.md)
 - [GetRecentSignagePointOrEosRequest](docs/GetRecentSignagePointOrEosRequest.md)
 - [GetRecentSignagePointOrEosRequestOneOf](docs/GetRecentSignagePointOrEosRequestOneOf.md)
 - [GetRecentSignagePointOrEosRequestOneOf1](docs/GetRecentSignagePointOrEosRequestOneOf1.md)
 - [GetRoutes200Response](docs/GetRoutes200Response.md)
 - [GetRoutes200ResponseAllOf](docs/GetRoutes200ResponseAllOf.md)
 - [GetUnfinishedBlockHeaders200Response](docs/GetUnfinishedBlockHeaders200Response.md)
 - [GetUnfinishedBlockHeaders200ResponseAllOf](docs/GetUnfinishedBlockHeaders200ResponseAllOf.md)
 - [InfusedChallengeChainSubSlot](docs/InfusedChallengeChainSubSlot.md)
 - [KSize](docs/KSize.md)
 - [MempoolItem](docs/MempoolItem.md)
 - [ModelApiResponse](docs/ModelApiResponse.md)
 - [NetworkInfo](docs/NetworkInfo.md)
 - [NodeType](docs/NodeType.md)
 - [Npc](docs/Npc.md)
 - [NpcResult](docs/NpcResult.md)
 - [OpenConnectionRequest](docs/OpenConnectionRequest.md)
 - [PoolTarget](docs/PoolTarget.md)
 - [ProofOfSpace](docs/ProofOfSpace.md)
 - [PushTx200Response](docs/PushTx200Response.md)
 - [PushTx200ResponseAllOf](docs/PushTx200ResponseAllOf.md)
 - [PushTxRequest](docs/PushTxRequest.md)
 - [RewardChainBlock](docs/RewardChainBlock.md)
 - [RewardChainBlockUnfinished](docs/RewardChainBlockUnfinished.md)
 - [RewardChainSubSlot](docs/RewardChainSubSlot.md)
 - [SignagePoint](docs/SignagePoint.md)
 - [SpendBundle](docs/SpendBundle.md)
 - [SubSlotProofs](docs/SubSlotProofs.md)
 - [TransactionsInfo](docs/TransactionsInfo.md)
 - [UnfinishedHeaderBlock](docs/UnfinishedHeaderBlock.md)
 - [VdfInfo](docs/VdfInfo.md)
 - [VdfProof](docs/VdfProof.md)


## Documentation for Authorization

Authentication schemes defined for the API:
### bearerAuth

- **Type**: HTTP basic authentication


## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author

hello@chia.net

