# openapi-java-client

Chia RPC
- API version: 1.7.1
  - Build date: 2023-05-11T13:32:18.313735300-04:00[America/New_York]

The Chia node and services come with a JSON RPC API server that allows you to access information and control the services.  These are accessible via HTTPS, WebSockets, or via client SDKs. The ports can be configured in `~/.chia/mainnet/config/config.yaml`.  The RPC ports should not be exposed to the internet. TLS certificates are used to secure the communication  [using mutualTLS](https://github.com/dkackman/chia-api/wiki/Mutual-TLS).
The harvester uses port 8560 by default.

  For more information, please visit [https://www.chia.net/](https://www.chia.net/)

*Automatically generated by the [OpenAPI Generator](https://openapi-generator.tech)*


## Requirements

Building the API client library requires:
1. Java 1.8+
2. Maven (3.8.3+)/Gradle (7.2+)

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn clean install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn clean deploy
```

Refer to the [OSSRH Guide](http://central.sonatype.org/pages/ossrh-guide.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
  <groupId>org.openapitools</groupId>
  <artifactId>openapi-java-client</artifactId>
  <version>1.7.1</version>
  <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
  repositories {
    mavenCentral()     // Needed if the 'openapi-java-client' jar has been published to maven central.
    mavenLocal()       // Needed if the 'openapi-java-client' jar has been published to the local maven repo.
  }

  dependencies {
     implementation "org.openapitools:openapi-java-client:1.7.1"
  }
```

### Others

At first generate the JAR by executing:

```shell
mvn clean package
```

Then manually install the following JARs:

* `target/openapi-java-client-1.7.1.jar`
* `target/lib/*.jar`

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.HarvesterApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://localhost:8560");
    

    HarvesterApi apiInstance = new HarvesterApi(defaultClient);
    AddPlotDirectoryRequest addPlotDirectoryRequest = new AddPlotDirectoryRequest(); // AddPlotDirectoryRequest | The directory name to add
    try {
      ModelApiResponse result = apiInstance.addPlotDirectory(addPlotDirectoryRequest);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling HarvesterApi#addPlotDirectory");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost:8560*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*HarvesterApi* | [**addPlotDirectory**](docs/HarvesterApi.md#addPlotDirectory) | **POST** /add_plot_directory | Add a plot directory to the harvester configuration.
*HarvesterApi* | [**deletePlot**](docs/HarvesterApi.md#deletePlot) | **POST** /delete_plot | Permanently delete a plot file.
*HarvesterApi* | [**getPlotDirectories**](docs/HarvesterApi.md#getPlotDirectories) | **POST** /get_plot_directories | Get the list of plot directories from the harvester configuration.
*HarvesterApi* | [**getPlots**](docs/HarvesterApi.md#getPlots) | **POST** /get_plots | Get information about the plots the harvester knows about.
*HarvesterApi* | [**refreshPlots**](docs/HarvesterApi.md#refreshPlots) | **POST** /refresh_plots | Refresh the list of plots.
*HarvesterApi* | [**removePlotDirectory**](docs/HarvesterApi.md#removePlotDirectory) | **POST** /remove_plot_directory | Removes a plot directory from the harveser configuration.
*SharedApi* | [**closeConnection**](docs/SharedApi.md#closeConnection) | **POST** /close_connection | Removes a connection.
*SharedApi* | [**getConnections**](docs/SharedApi.md#getConnections) | **POST** /get_connections | Retrieve the list of connections.
*SharedApi* | [**getRoutes**](docs/SharedApi.md#getRoutes) | **POST** /get_routes | Retrieve the list of routes exposed by the service.
*SharedApi* | [**healthz**](docs/SharedApi.md#healthz) | **POST** /healthz | Heartbeat.
*SharedApi* | [**openConnection**](docs/SharedApi.md#openConnection) | **POST** /open_connection | Add a connection to another node.
*SharedApi* | [**stopNode**](docs/SharedApi.md#stopNode) | **POST** /stop_node | Stop the node.


## Documentation for Models

 - [AddPlotDirectoryRequest](docs/AddPlotDirectoryRequest.md)
 - [CloseConnectionRequest](docs/CloseConnectionRequest.md)
 - [ConnectionInfo](docs/ConnectionInfo.md)
 - [DeletePlotRequest](docs/DeletePlotRequest.md)
 - [GetConnections200Response](docs/GetConnections200Response.md)
 - [GetConnections200ResponseAllOf](docs/GetConnections200ResponseAllOf.md)
 - [GetPlotDirectories200Response](docs/GetPlotDirectories200Response.md)
 - [GetPlotDirectories200ResponseAllOf](docs/GetPlotDirectories200ResponseAllOf.md)
 - [GetPlots200Response](docs/GetPlots200Response.md)
 - [GetPlots200ResponseAllOf](docs/GetPlots200ResponseAllOf.md)
 - [GetRoutes200Response](docs/GetRoutes200Response.md)
 - [GetRoutes200ResponseAllOf](docs/GetRoutes200ResponseAllOf.md)
 - [KSize](docs/KSize.md)
 - [ModelApiResponse](docs/ModelApiResponse.md)
 - [NodeType](docs/NodeType.md)
 - [OpenConnectionRequest](docs/OpenConnectionRequest.md)
 - [PlotInfo](docs/PlotInfo.md)


## Documentation for Authorization

Authentication schemes defined for the API:
### bearerAuth

- **Type**: HTTP basic authentication


## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author

hello@chia.net

