# openapi-java-client

Chia RPC
- API version: 1.7.1
  - Build date: 2023-05-11T12:44:31.667508-04:00[America/New_York]

The Chia node and services come with a JSON RPC API server that allows you to access information and control the services.  These are accessible via HTTPS, WebSockets, or via client SDKs. The ports can be configured in `~/.chia/mainnet/config/config.yaml`.  The RPC ports should not be exposed to the internet. TLS certificates are used to secure the communication  [using mutualTLS](https://github.com/dkackman/chia-api/wiki/Mutual-TLS).
The wallet uses port 9256 by default.

  For more information, please visit [https://www.chia.net/](https://www.chia.net/)

*Automatically generated by the [OpenAPI Generator](https://openapi-generator.tech)*


## Requirements

Building the API client library requires:
1. Java 1.8+
2. Maven (3.8.3+)/Gradle (7.2+)

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn clean install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn clean deploy
```

Refer to the [OSSRH Guide](http://central.sonatype.org/pages/ossrh-guide.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
  <groupId>org.openapitools</groupId>
  <artifactId>openapi-java-client</artifactId>
  <version>1.7.1</version>
  <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
  repositories {
    mavenCentral()     // Needed if the 'openapi-java-client' jar has been published to maven central.
    mavenLocal()       // Needed if the 'openapi-java-client' jar has been published to the local maven repo.
  }

  dependencies {
     implementation "org.openapitools:openapi-java-client:1.7.1"
  }
```

### Others

At first generate the JAR by executing:

```shell
mvn clean package
```

Then manually install the following JARs:

* `target/openapi-java-client-1.7.1.jar`
* `target/lib/*.jar`

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.CatWalletApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://localhost:9256");
    

    CatWalletApi apiInstance = new CatWalletApi(defaultClient);
    CancelOfferRequest cancelOfferRequest = new CancelOfferRequest(); // CancelOfferRequest | 
    try {
      ModelApiResponse result = apiInstance.cancelOffer(cancelOfferRequest);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling CatWalletApi#cancelOffer");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost:9256*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CatWalletApi* | [**cancelOffer**](docs/CatWalletApi.md#cancelOffer) | **POST** /cancel_offer | Cancels an offer.
*CatWalletApi* | [**cancelOffers**](docs/CatWalletApi.md#cancelOffers) | **POST** /cancel_offers | Cancels multiple offers.
*CatWalletApi* | [**catAssetIdToName**](docs/CatWalletApi.md#catAssetIdToName) | **POST** /cat_asset_id_to_name | Gets the name and wallet id associated with an asset id.
*CatWalletApi* | [**catGetAssetId**](docs/CatWalletApi.md#catGetAssetId) | **POST** /cat_get_asset_id | Gets the asset id of the CAT wallet.
*CatWalletApi* | [**catGetName**](docs/CatWalletApi.md#catGetName) | **POST** /cat_get_name | Gets the name of the CAT wallet.
*CatWalletApi* | [**catSetName**](docs/CatWalletApi.md#catSetName) | **POST** /cat_set_name | Sets the name of the CAT wallet.
*CatWalletApi* | [**catSpend**](docs/CatWalletApi.md#catSpend) | **POST** /cat_spend | Spends an amount from the given wallet.
*CatWalletApi* | [**checkOfferValidity**](docs/CatWalletApi.md#checkOfferValidity) | **POST** /check_offer_validity | Checks the validity of an offer.
*CatWalletApi* | [**createOfferForIds**](docs/CatWalletApi.md#createOfferForIds) | **POST** /create_offer_for_ids | Creates an offer.
*CatWalletApi* | [**getAllOffers**](docs/CatWalletApi.md#getAllOffers) | **POST** /get_all_offers | Retrieves offers.
*CatWalletApi* | [**getCatList**](docs/CatWalletApi.md#getCatList) | **POST** /get_cat_list | Retrieves the list of CATs.
*CatWalletApi* | [**getOffer**](docs/CatWalletApi.md#getOffer) | **POST** /get_offer | Retrieves an offer.
*CatWalletApi* | [**getOfferSummary**](docs/CatWalletApi.md#getOfferSummary) | **POST** /get_offer_summary | Get the summary of a given offer.
*CatWalletApi* | [**getOffersCount**](docs/CatWalletApi.md#getOffersCount) | **POST** /get_offers_count | Retrieves the number of offers.
*CatWalletApi* | [**getStrayCats**](docs/CatWalletApi.md#getStrayCats) | **POST** /get_stray_cats | Get a list of all unacknowledged CATs.
*CatWalletApi* | [**selectCoins**](docs/CatWalletApi.md#selectCoins) | **POST** /select_coins | Returns a set of coins that can be used for generating a new transaction.
*CatWalletApi* | [**takeOffer**](docs/CatWalletApi.md#takeOffer) | **POST** /take_offer | Takes an offer.
*CoinsApi* | [**getCoinRecordsByNames**](docs/CoinsApi.md#getCoinRecordsByNames) | **POST** /get_coin_records_by_names | Retrieves the coins for given coin IDs.
*DataLayerWalletApi* | [**createNewDl**](docs/DataLayerWalletApi.md#createNewDl) | **POST** /create_new_dl | Initialize the new data layer wallets.
*DataLayerWalletApi* | [**dlDeleteMirror**](docs/DataLayerWalletApi.md#dlDeleteMirror) | **POST** /dl_delete_mirror | Remove an existing mirror for a specific singleton.
*DataLayerWalletApi* | [**dlGetMirrors**](docs/DataLayerWalletApi.md#dlGetMirrors) | **POST** /dl_get_mirrors | Get all of the mirrors for a specific singleton.
*DataLayerWalletApi* | [**dlHistory**](docs/DataLayerWalletApi.md#dlHistory) | **POST** /dl_history | Get the singleton record for the latest singleton of a launcher ID.
*DataLayerWalletApi* | [**dlLatestSingleton**](docs/DataLayerWalletApi.md#dlLatestSingleton) | **POST** /dl_latest_singleton | Get the singleton records that contain the specified root.
*DataLayerWalletApi* | [**dlNewMirror**](docs/DataLayerWalletApi.md#dlNewMirror) | **POST** /dl_new_mirror | Add a new on chain message for a specific singleton.
*DataLayerWalletApi* | [**dlOwnedSingletons**](docs/DataLayerWalletApi.md#dlOwnedSingletons) | **POST** /dl_owned_singletons | Get all owned singleton records.
*DataLayerWalletApi* | [**dlSingletonsByRoot**](docs/DataLayerWalletApi.md#dlSingletonsByRoot) | **POST** /dl_singletons_by_root | Get the singleton records that contain the specified root.
*DataLayerWalletApi* | [**dlStopTracking**](docs/DataLayerWalletApi.md#dlStopTracking) | **POST** /dl_stop_tracking | Stop tracking the data layer wallets.
*DataLayerWalletApi* | [**dlTrackNew**](docs/DataLayerWalletApi.md#dlTrackNew) | **POST** /dl_track_new | Track the new data layer wallet
*DataLayerWalletApi* | [**dlUpdateMultiple**](docs/DataLayerWalletApi.md#dlUpdateMultiple) | **POST** /dl_update_multiple | Stop the node.
*DataLayerWalletApi* | [**dlUpdateRoot**](docs/DataLayerWalletApi.md#dlUpdateRoot) | **POST** /dl_update_root | Stop the node.
*DidWalletApi* | [**didCreateAttest**](docs/DidWalletApi.md#didCreateAttest) | **POST** /did_create_attest | Creates an attestment for the given DID wallet.
*DidWalletApi* | [**didCreateBackupFile**](docs/DidWalletApi.md#didCreateBackupFile) | **POST** /did_create_backup_file | Creates a backup file for the given DID wallet.
*DidWalletApi* | [**didFindLostDid**](docs/DidWalletApi.md#didFindLostDid) | **POST** /did_find_lost_did | Recover a missing or unspendable DID wallet by a coin id of the DID.
*DidWalletApi* | [**didGetCurrentCoinInfo**](docs/DidWalletApi.md#didGetCurrentCoinInfo) | **POST** /did_get_current_coin_info | Gets information about the DID wallets current coin.
*DidWalletApi* | [**didGetDid**](docs/DidWalletApi.md#didGetDid) | **POST** /did_get_did | Retrieves the distributed identity for a given wallet.
*DidWalletApi* | [**didGetInfo**](docs/DidWalletApi.md#didGetInfo) | **POST** /did_get_info | Retreives information about a DID.
*DidWalletApi* | [**didGetInformationNeededForRecovery**](docs/DidWalletApi.md#didGetInformationNeededForRecovery) | **POST** /did_get_information_needed_for_recovery | Retrieves the recovery information needed for the given DID wallet.
*DidWalletApi* | [**didGetMetadata**](docs/DidWalletApi.md#didGetMetadata) | **POST** /did_get_metadata | Gets the metadata of a DID wallet.
*DidWalletApi* | [**didGetPubkey**](docs/DidWalletApi.md#didGetPubkey) | **POST** /did_get_pubkey | Retrieves the public key for the given DID wallet.
*DidWalletApi* | [**didGetRecoveryList**](docs/DidWalletApi.md#didGetRecoveryList) | **POST** /did_get_recovery_list | Retrieves the recovery list for a given DID wallet.
*DidWalletApi* | [**didGetWalletName**](docs/DidWalletApi.md#didGetWalletName) | **POST** /did_get_wallet_name | Gets the name of a DID wallet.
*DidWalletApi* | [**didMessageSpend**](docs/DidWalletApi.md#didMessageSpend) | **POST** /did_message_spend | Spends a DID message.
*DidWalletApi* | [**didRecoverySpend**](docs/DidWalletApi.md#didRecoverySpend) | **POST** /did_recovery_spend | Spend from the given DID wallet.
*DidWalletApi* | [**didSetWalletName**](docs/DidWalletApi.md#didSetWalletName) | **POST** /did_set_wallet_name | Sets the name of a DID wallet.
*DidWalletApi* | [**didTransferDid**](docs/DidWalletApi.md#didTransferDid) | **POST** /did_transfer_did | Transfer a DID to another owner.
*DidWalletApi* | [**didUpdateMetadata**](docs/DidWalletApi.md#didUpdateMetadata) | **POST** /did_update_metadata | Updates the metadata for a DID wallet.
*DidWalletApi* | [**didUpdateRecoveryIds**](docs/DidWalletApi.md#didUpdateRecoveryIds) | **POST** /did_update_recovery_ids | Updates the recovery ids for a DID wallet.
*KeyManagementApi* | [**addKey**](docs/KeyManagementApi.md#addKey) | **POST** /add_key | Generates a new mnemonic phrase.
*KeyManagementApi* | [**checkDeleteKey**](docs/KeyManagementApi.md#checkDeleteKey) | **POST** /check_delete_key | Determines if it is safe to delete a private key.
*KeyManagementApi* | [**deleteKey**](docs/KeyManagementApi.md#deleteKey) | **POST** /delete_key | Deletes all keys which have the given public key fingerprint.
*KeyManagementApi* | [**generateMnemonic**](docs/KeyManagementApi.md#generateMnemonic) | **POST** /generate_mnemonic | Generates a new mnemonic phrase.
*KeyManagementApi* | [**getLoggedInFingerprint**](docs/KeyManagementApi.md#getLoggedInFingerprint) | **POST** /get_logged_in_fingerprint | Retrieves the logged in fingerprint.
*KeyManagementApi* | [**getPrivateKey**](docs/KeyManagementApi.md#getPrivateKey) | **POST** /get_private_key | Retrieves the private key by fingerprint.
*KeyManagementApi* | [**getPublicKeys**](docs/KeyManagementApi.md#getPublicKeys) | **POST** /get_public_keys | Retrieves all public keys on the node.
*KeyManagementApi* | [**logIn**](docs/KeyManagementApi.md#logIn) | **POST** /log_in | Logs in the wallet with a specific key.
*KeyManagementApi* | [**verifySignature**](docs/KeyManagementApi.md#verifySignature) | **POST** /verify_signature | Given a public key, message and signature, verify if it is valid.
*KeyManagementApi* | [**walletDeleteAllKeys**](docs/KeyManagementApi.md#walletDeleteAllKeys) | **POST** /delete_all_keys | Deletes all keys from the keychain.
*NftWalletApi* | [**nftAddUri**](docs/NftWalletApi.md#nftAddUri) | **POST** /nft_add_uri | Adds an Uri to an NFT.
*NftWalletApi* | [**nftCalculateRoyalties**](docs/NftWalletApi.md#nftCalculateRoyalties) | **POST** /nft_calculate_royalties | Transfers an NFT to another address.
*NftWalletApi* | [**nftCountNfts**](docs/NftWalletApi.md#nftCountNfts) | **POST** /nft_count_nfts | Retreives the number of NFTs in a wallet.
*NftWalletApi* | [**nftGetByDid**](docs/NftWalletApi.md#nftGetByDid) | **POST** /nft_get_by_did | Gets an NFT wallet by its DID.
*NftWalletApi* | [**nftGetInfo**](docs/NftWalletApi.md#nftGetInfo) | **POST** /nft_get_info | Gets info about an NFT.
*NftWalletApi* | [**nftGetNfts**](docs/NftWalletApi.md#nftGetNfts) | **POST** /nft_get_nfts | Gets NFTs from a wallet.
*NftWalletApi* | [**nftGetWalletDid**](docs/NftWalletApi.md#nftGetWalletDid) | **POST** /nft_get_wallet_did | Gets the DID for an NFT wallet.
*NftWalletApi* | [**nftGetWalletsWithDids**](docs/NftWalletApi.md#nftGetWalletsWithDids) | **POST** /nft_get_wallets_with_dids | Gets all the wallets with a DID.
*NftWalletApi* | [**nftMintBulk**](docs/NftWalletApi.md#nftMintBulk) | **POST** /nft_mint_bulk | Mints NFTs in bulk.
*NftWalletApi* | [**nftMintNft**](docs/NftWalletApi.md#nftMintNft) | **POST** /nft_mint_nft | Mints an NFT.
*NftWalletApi* | [**nftSetDidBulk**](docs/NftWalletApi.md#nftSetDidBulk) | **POST** /nft_set_did_bulk | Bulk set DID for NFTs across different wallets.
*NftWalletApi* | [**nftSetNftDid**](docs/NftWalletApi.md#nftSetNftDid) | **POST** /nft_set_nft_did | Sets the DID of an NFT.
*NftWalletApi* | [**nftSetNftStatus**](docs/NftWalletApi.md#nftSetNftStatus) | **POST** /nft_set_nft_status | Sets the status of an NFT.
*NftWalletApi* | [**nftTransferBulk**](docs/NftWalletApi.md#nftTransferBulk) | **POST** /nft_transfer_bulk | Bulk transfer NFTs to an address.
*NftWalletApi* | [**nftTransferNft**](docs/NftWalletApi.md#nftTransferNft) | **POST** /nft_transfer_nft | Transfers an NFT to another address.
*NotificationsApi* | [**deleteNotifications**](docs/NotificationsApi.md#deleteNotifications) | **POST** /delete_notifications | Deletes notifications.
*NotificationsApi* | [**getNotifications**](docs/NotificationsApi.md#getNotifications) | **POST** /get_notifications | Retreives notifications.
*NotificationsApi* | [**sendNotification**](docs/NotificationsApi.md#sendNotification) | **POST** /send_notification | Sends a notification.
*NotificationsApi* | [**signMessageByAddress**](docs/NotificationsApi.md#signMessageByAddress) | **POST** /sign_message_by_address | Given a derived P2 address, sign the message by its private key.
*NotificationsApi* | [**signMessageById**](docs/NotificationsApi.md#signMessageById) | **POST** /sign_message_by_id | Given a NFT/DID ID, sign the message by the P2 private key.
*PoolWalletApi* | [**pwAbsorbRewards**](docs/PoolWalletApi.md#pwAbsorbRewards) | **POST** /pw_absorb_rewards | Perform a sweep of the p2_singleton rewards controlled by the pool wallet singleton.
*PoolWalletApi* | [**pwJoinPool**](docs/PoolWalletApi.md#pwJoinPool) | **POST** /pw_join_pool | Joins the given wallet to a pool.
*PoolWalletApi* | [**pwSelfPool**](docs/PoolWalletApi.md#pwSelfPool) | **POST** /pw_self_pool | Removes the given wallet to a pool.
*PoolWalletApi* | [**pwStatus**](docs/PoolWalletApi.md#pwStatus) | **POST** /pw_status | Return the complete state of the given Pool wallet.
*SharedApi* | [**closeConnection**](docs/SharedApi.md#closeConnection) | **POST** /close_connection | Removes a connection.
*SharedApi* | [**getConnections**](docs/SharedApi.md#getConnections) | **POST** /get_connections | Retrieve the list of connections.
*SharedApi* | [**getRoutes**](docs/SharedApi.md#getRoutes) | **POST** /get_routes | Retrieve the list of routes exposed by the service.
*SharedApi* | [**healthz**](docs/SharedApi.md#healthz) | **POST** /healthz | Heartbeat.
*SharedApi* | [**openConnection**](docs/SharedApi.md#openConnection) | **POST** /open_connection | Add a connection to another node.
*SharedApi* | [**stopNode**](docs/SharedApi.md#stopNode) | **POST** /stop_node | Stop the node.
*WalletApi* | [**createSignedTransaction**](docs/WalletApi.md#createSignedTransaction) | **POST** /create_signed_transaction | Creates and signs a transaction.
*WalletApi* | [**deleteUnconfirmedTransactions**](docs/WalletApi.md#deleteUnconfirmedTransactions) | **POST** /delete_unconfirmed_transactions | Delete all unconfirmed transactions for a given wallet.
*WalletApi* | [**extendDerivationIndex**](docs/WalletApi.md#extendDerivationIndex) | **POST** /extend_derivation_index | Extends the current derivation index.
*WalletApi* | [**getCurrentDerivationIndex**](docs/WalletApi.md#getCurrentDerivationIndex) | **POST** /get_current_derivation_index | Gets the current derivation index.
*WalletApi* | [**getFarmedAmount**](docs/WalletApi.md#getFarmedAmount) | **POST** /get_farmed_amount | Retrieves the amount farmed.
*WalletApi* | [**getNextAddress**](docs/WalletApi.md#getNextAddress) | **POST** /get_next_address | Returns a new address.
*WalletApi* | [**getSpendableCoins**](docs/WalletApi.md#getSpendableCoins) | **POST** /get_spendable_coins | Retrieves all spendable coins in a wallet.
*WalletApi* | [**getTransaction**](docs/WalletApi.md#getTransaction) | **POST** /get_transaction | Retrieves a specific transaction.
*WalletApi* | [**getTransactionCount**](docs/WalletApi.md#getTransactionCount) | **POST** /get_transaction_count | Retrieves the number of transactions for a wallet.
*WalletApi* | [**getTransactionMemo**](docs/WalletApi.md#getTransactionMemo) | **POST** /get_transaction_memo | Retreives the memo from a transaction.
*WalletApi* | [**getTransactions**](docs/WalletApi.md#getTransactions) | **POST** /get_transactions | Retrieves a list of trnsactions from a wallet.
*WalletApi* | [**getWalletBalance**](docs/WalletApi.md#getWalletBalance) | **POST** /get_wallet_balance | Retrieves the balance of a specific wallet.
*WalletApi* | [**sendTransaction**](docs/WalletApi.md#sendTransaction) | **POST** /send_transaction | Sends an amount of mojo from the given wallet to the given address.
*WalletApi* | [**sendTransactionMulti**](docs/WalletApi.md#sendTransactionMulti) | **POST** /send_transaction_multi | Sends multiple transactions from then given wallet.
*WalletManagementApi* | [**createNewWallet**](docs/WalletManagementApi.md#createNewWallet) | **POST** /create_new_wallet | Creates a new wallet.
*WalletManagementApi* | [**getWallets**](docs/WalletManagementApi.md#getWallets) | **POST** /get_wallets | Retrieves all of the wallets on the node.
*WalletNodeApi* | [**getHeightInfo**](docs/WalletNodeApi.md#getHeightInfo) | **POST** /get_height_info | Retrieves the sync height of the wallet.
*WalletNodeApi* | [**getSyncStatus**](docs/WalletNodeApi.md#getSyncStatus) | **POST** /get_sync_status | Retrieves the sync status of the wallet.
*WalletNodeApi* | [**getTimestampForHeight**](docs/WalletNodeApi.md#getTimestampForHeight) | **POST** /get_timestamp_for_height | Retreive the timestamp for a given block height.
*WalletNodeApi* | [**pushTransactions**](docs/WalletNodeApi.md#pushTransactions) | **POST** /push_transactions | Pushes multiple transactions spend bundle to the mempool and blockchain.
*WalletNodeApi* | [**setWalletResyncOnStartup**](docs/WalletNodeApi.md#setWalletResyncOnStartup) | **POST** /set_wallet_resync_on_startup | Resync the current logged in wallet. The transaction and offer records will be kept.
*WalletNodeApi* | [**walletGetNetworkInfo**](docs/WalletNodeApi.md#walletGetNetworkInfo) | **POST** /get_network_info | Retrieves some information about the current network.
*WalletNodeApi* | [**walletPushTx**](docs/WalletNodeApi.md#walletPushTx) | **POST** /push_tx | Pushes a transaction/spend bundle to the mempool and blockchain.


## Documentation for Models

 - [AddKey200Response](docs/AddKey200Response.md)
 - [AddKey200ResponseAllOf](docs/AddKey200ResponseAllOf.md)
 - [AmountWithPuzzlehash](docs/AmountWithPuzzlehash.md)
 - [CancelOfferRequest](docs/CancelOfferRequest.md)
 - [CancelOffersRequest](docs/CancelOffersRequest.md)
 - [CatAssetIdToName200Response](docs/CatAssetIdToName200Response.md)
 - [CatAssetIdToNameRequest](docs/CatAssetIdToNameRequest.md)
 - [CatGetAssetId200Response](docs/CatGetAssetId200Response.md)
 - [CatGetAssetId200ResponseAllOf](docs/CatGetAssetId200ResponseAllOf.md)
 - [CatInfo](docs/CatInfo.md)
 - [CatSpendRequest](docs/CatSpendRequest.md)
 - [CheckDeleteKey200Response](docs/CheckDeleteKey200Response.md)
 - [CheckDeleteKey200ResponseAllOf](docs/CheckDeleteKey200ResponseAllOf.md)
 - [CheckOfferValidity200Response](docs/CheckOfferValidity200Response.md)
 - [CheckOfferValidity200ResponseAllOf](docs/CheckOfferValidity200ResponseAllOf.md)
 - [CheckOfferValidityRequest](docs/CheckOfferValidityRequest.md)
 - [CloseConnectionRequest](docs/CloseConnectionRequest.md)
 - [Coin](docs/Coin.md)
 - [CoinAnnouncement](docs/CoinAnnouncement.md)
 - [CoinRecord](docs/CoinRecord.md)
 - [CoinSearchOptions](docs/CoinSearchOptions.md)
 - [CoinSpend](docs/CoinSpend.md)
 - [ConnectionInfo](docs/ConnectionInfo.md)
 - [CreateNewDl200Response](docs/CreateNewDl200Response.md)
 - [CreateNewDl200ResponseAllOf](docs/CreateNewDl200ResponseAllOf.md)
 - [CreateNewDlRequest](docs/CreateNewDlRequest.md)
 - [CreateNewWallet200Response](docs/CreateNewWallet200Response.md)
 - [CreateNewWallet200ResponseOneOf](docs/CreateNewWallet200ResponseOneOf.md)
 - [CreateNewWallet200ResponseOneOf1](docs/CreateNewWallet200ResponseOneOf1.md)
 - [CreateNewWallet200ResponseOneOf2](docs/CreateNewWallet200ResponseOneOf2.md)
 - [CreateNewWallet200ResponseOneOf3](docs/CreateNewWallet200ResponseOneOf3.md)
 - [CreateNewWallet200ResponseOneOf4](docs/CreateNewWallet200ResponseOneOf4.md)
 - [CreateNewWalletRequest](docs/CreateNewWalletRequest.md)
 - [CreateNewWalletRequestOneOf](docs/CreateNewWalletRequestOneOf.md)
 - [CreateNewWalletRequestOneOf1](docs/CreateNewWalletRequestOneOf1.md)
 - [CreateNewWalletRequestOneOf1OneOf](docs/CreateNewWalletRequestOneOf1OneOf.md)
 - [CreateNewWalletRequestOneOf1OneOf1](docs/CreateNewWalletRequestOneOf1OneOf1.md)
 - [CreateNewWalletRequestOneOf2](docs/CreateNewWalletRequestOneOf2.md)
 - [CreateNewWalletRequestOneOf3](docs/CreateNewWalletRequestOneOf3.md)
 - [CreateOfferForIds200Response](docs/CreateOfferForIds200Response.md)
 - [CreateOfferForIds200ResponseAllOf](docs/CreateOfferForIds200ResponseAllOf.md)
 - [CreateOfferForIdsRequest](docs/CreateOfferForIdsRequest.md)
 - [CreateSignedTransaction200Response](docs/CreateSignedTransaction200Response.md)
 - [CreateSignedTransaction200ResponseAllOf](docs/CreateSignedTransaction200ResponseAllOf.md)
 - [CreateSignedTransactionRequest](docs/CreateSignedTransactionRequest.md)
 - [CreateSignedTransactionRequestAllOf](docs/CreateSignedTransactionRequestAllOf.md)
 - [DeleteNotificationsRequest](docs/DeleteNotificationsRequest.md)
 - [DidCreateAttest200Response](docs/DidCreateAttest200Response.md)
 - [DidCreateAttest200ResponseAllOf](docs/DidCreateAttest200ResponseAllOf.md)
 - [DidCreateAttestRequest](docs/DidCreateAttestRequest.md)
 - [DidCreateBackupFile200Response](docs/DidCreateBackupFile200Response.md)
 - [DidCreateBackupFile200ResponseAllOf](docs/DidCreateBackupFile200ResponseAllOf.md)
 - [DidFindLostDid200Response](docs/DidFindLostDid200Response.md)
 - [DidFindLostDid200ResponseAllOf](docs/DidFindLostDid200ResponseAllOf.md)
 - [DidFindLostDidRequest](docs/DidFindLostDidRequest.md)
 - [DidGetCurrentCoinInfo200Response](docs/DidGetCurrentCoinInfo200Response.md)
 - [DidGetCurrentCoinInfo200ResponseAllOf](docs/DidGetCurrentCoinInfo200ResponseAllOf.md)
 - [DidGetDid200Response](docs/DidGetDid200Response.md)
 - [DidGetDid200ResponseAllOf](docs/DidGetDid200ResponseAllOf.md)
 - [DidGetInfo200Response](docs/DidGetInfo200Response.md)
 - [DidGetInfo200ResponseAllOf](docs/DidGetInfo200ResponseAllOf.md)
 - [DidGetInfoRequest](docs/DidGetInfoRequest.md)
 - [DidGetInformationNeededForRecovery200Response](docs/DidGetInformationNeededForRecovery200Response.md)
 - [DidGetInformationNeededForRecovery200ResponseAllOf](docs/DidGetInformationNeededForRecovery200ResponseAllOf.md)
 - [DidGetMetadata200Response](docs/DidGetMetadata200Response.md)
 - [DidGetMetadata200ResponseAllOf](docs/DidGetMetadata200ResponseAllOf.md)
 - [DidGetPubkey200Response](docs/DidGetPubkey200Response.md)
 - [DidGetPubkey200ResponseAllOf](docs/DidGetPubkey200ResponseAllOf.md)
 - [DidGetRecoveryList200Response](docs/DidGetRecoveryList200Response.md)
 - [DidGetRecoveryList200ResponseAllOf](docs/DidGetRecoveryList200ResponseAllOf.md)
 - [DidGetWalletName200Response](docs/DidGetWalletName200Response.md)
 - [DidGetWalletName200ResponseAllOf](docs/DidGetWalletName200ResponseAllOf.md)
 - [DidMessageSpendRequest](docs/DidMessageSpendRequest.md)
 - [DidRecoverySpend200Response](docs/DidRecoverySpend200Response.md)
 - [DidRecoverySpend200ResponseAllOf](docs/DidRecoverySpend200ResponseAllOf.md)
 - [DidRecoverySpendRequest](docs/DidRecoverySpendRequest.md)
 - [DidSetWalletName200Response](docs/DidSetWalletName200Response.md)
 - [DidSetWalletNameRequest](docs/DidSetWalletNameRequest.md)
 - [DidTransferDid200Response](docs/DidTransferDid200Response.md)
 - [DidTransferDid200ResponseAllOf](docs/DidTransferDid200ResponseAllOf.md)
 - [DidTransferDidRequest](docs/DidTransferDidRequest.md)
 - [DidUpdateMetadata200Response](docs/DidUpdateMetadata200Response.md)
 - [DidUpdateMetadataRequest](docs/DidUpdateMetadataRequest.md)
 - [DidUpdateRecoveryIdsRequest](docs/DidUpdateRecoveryIdsRequest.md)
 - [DlDeleteMirrorRequest](docs/DlDeleteMirrorRequest.md)
 - [DlGetMirrors200Response](docs/DlGetMirrors200Response.md)
 - [DlGetMirrors200ResponseAllOf](docs/DlGetMirrors200ResponseAllOf.md)
 - [DlHistory200Response](docs/DlHistory200Response.md)
 - [DlHistory200ResponseAllOf](docs/DlHistory200ResponseAllOf.md)
 - [DlHistoryRequest](docs/DlHistoryRequest.md)
 - [DlLatestSingleton200Response](docs/DlLatestSingleton200Response.md)
 - [DlLatestSingleton200ResponseAllOf](docs/DlLatestSingleton200ResponseAllOf.md)
 - [DlLatestSingletonRequest](docs/DlLatestSingletonRequest.md)
 - [DlNewMirror200Response](docs/DlNewMirror200Response.md)
 - [DlNewMirror200ResponseAllOf](docs/DlNewMirror200ResponseAllOf.md)
 - [DlNewMirrorRequest](docs/DlNewMirrorRequest.md)
 - [DlOwnedSingletons200Response](docs/DlOwnedSingletons200Response.md)
 - [DlOwnedSingletons200ResponseAllOf](docs/DlOwnedSingletons200ResponseAllOf.md)
 - [DlSingletonsByRoot200Response](docs/DlSingletonsByRoot200Response.md)
 - [DlSingletonsByRoot200ResponseAllOf](docs/DlSingletonsByRoot200ResponseAllOf.md)
 - [DlTrackNewRequest](docs/DlTrackNewRequest.md)
 - [DlUpdateMultiple200Response](docs/DlUpdateMultiple200Response.md)
 - [DlUpdateMultiple200ResponseAllOf](docs/DlUpdateMultiple200ResponseAllOf.md)
 - [DlUpdateMultipleRequest](docs/DlUpdateMultipleRequest.md)
 - [DlUpdateMultipleRequestUpdatesInner](docs/DlUpdateMultipleRequestUpdatesInner.md)
 - [DlUpdateRoot200Response](docs/DlUpdateRoot200Response.md)
 - [DlUpdateRoot200ResponseAllOf](docs/DlUpdateRoot200ResponseAllOf.md)
 - [DlUpdateRootRequest](docs/DlUpdateRootRequest.md)
 - [ExtendDerivationIndexRequest](docs/ExtendDerivationIndexRequest.md)
 - [FarmerRewards](docs/FarmerRewards.md)
 - [GetAllOffers200Response](docs/GetAllOffers200Response.md)
 - [GetAllOffers200ResponseAllOf](docs/GetAllOffers200ResponseAllOf.md)
 - [GetAllOffersRequest](docs/GetAllOffersRequest.md)
 - [GetCatList200Response](docs/GetCatList200Response.md)
 - [GetCatList200ResponseAllOf](docs/GetCatList200ResponseAllOf.md)
 - [GetCoinRecordsByNames200Response](docs/GetCoinRecordsByNames200Response.md)
 - [GetCoinRecordsByNamesRequest](docs/GetCoinRecordsByNamesRequest.md)
 - [GetCoinRecordsByNamesRequestAllOf](docs/GetCoinRecordsByNamesRequestAllOf.md)
 - [GetConnections200Response](docs/GetConnections200Response.md)
 - [GetConnections200ResponseAllOf](docs/GetConnections200ResponseAllOf.md)
 - [GetCurrentDerivationIndex200Response](docs/GetCurrentDerivationIndex200Response.md)
 - [GetCurrentDerivationIndex200ResponseAllOf](docs/GetCurrentDerivationIndex200ResponseAllOf.md)
 - [GetFarmedAmount200Response](docs/GetFarmedAmount200Response.md)
 - [GetHeightInfo200Response](docs/GetHeightInfo200Response.md)
 - [GetHeightInfo200ResponseAllOf](docs/GetHeightInfo200ResponseAllOf.md)
 - [GetNextAddress200Response](docs/GetNextAddress200Response.md)
 - [GetNextAddress200ResponseAllOf](docs/GetNextAddress200ResponseAllOf.md)
 - [GetNextAddressRequest](docs/GetNextAddressRequest.md)
 - [GetNotifications200Response](docs/GetNotifications200Response.md)
 - [GetNotifications200ResponseAllOf](docs/GetNotifications200ResponseAllOf.md)
 - [GetNotifications200ResponseAllOfNotificationsInner](docs/GetNotifications200ResponseAllOfNotificationsInner.md)
 - [GetNotificationsRequest](docs/GetNotificationsRequest.md)
 - [GetOffer200Response](docs/GetOffer200Response.md)
 - [GetOffer200ResponseAllOf](docs/GetOffer200ResponseAllOf.md)
 - [GetOfferRequest](docs/GetOfferRequest.md)
 - [GetOfferSummary200Response](docs/GetOfferSummary200Response.md)
 - [GetOfferSummary200ResponseAllOf](docs/GetOfferSummary200ResponseAllOf.md)
 - [GetOfferSummary200ResponseAllOfOneOf](docs/GetOfferSummary200ResponseAllOfOneOf.md)
 - [GetOfferSummary200ResponseAllOfOneOf1](docs/GetOfferSummary200ResponseAllOfOneOf1.md)
 - [GetOfferSummary200ResponseAllOfOneOf1Summary](docs/GetOfferSummary200ResponseAllOfOneOf1Summary.md)
 - [GetOfferSummary200ResponseAllOfOneOfOfferedInner](docs/GetOfferSummary200ResponseAllOfOneOfOfferedInner.md)
 - [GetOfferSummary200ResponseAllOfOneOfOfferedInnerDependenciesInner](docs/GetOfferSummary200ResponseAllOfOneOfOfferedInnerDependenciesInner.md)
 - [GetOfferSummaryRequest](docs/GetOfferSummaryRequest.md)
 - [GetOffersCount200Response](docs/GetOffersCount200Response.md)
 - [GetOffersCount200ResponseAllOf](docs/GetOffersCount200ResponseAllOf.md)
 - [GetPrivateKey200Response](docs/GetPrivateKey200Response.md)
 - [GetPrivateKey200ResponseOneOf](docs/GetPrivateKey200ResponseOneOf.md)
 - [GetPrivateKey200ResponseOneOf1](docs/GetPrivateKey200ResponseOneOf1.md)
 - [GetPublicKeys200Response](docs/GetPublicKeys200Response.md)
 - [GetPublicKeys200ResponseOneOf](docs/GetPublicKeys200ResponseOneOf.md)
 - [GetPublicKeys200ResponseOneOf1](docs/GetPublicKeys200ResponseOneOf1.md)
 - [GetRoutes200Response](docs/GetRoutes200Response.md)
 - [GetRoutes200ResponseAllOf](docs/GetRoutes200ResponseAllOf.md)
 - [GetSpendableCoins200Response](docs/GetSpendableCoins200Response.md)
 - [GetSpendableCoins200ResponseAllOf](docs/GetSpendableCoins200ResponseAllOf.md)
 - [GetSpendableCoinsRequest](docs/GetSpendableCoinsRequest.md)
 - [GetStrayCats200Response](docs/GetStrayCats200Response.md)
 - [GetStrayCats200ResponseAllOf](docs/GetStrayCats200ResponseAllOf.md)
 - [GetSyncStatus200Response](docs/GetSyncStatus200Response.md)
 - [GetSyncStatus200ResponseAllOf](docs/GetSyncStatus200ResponseAllOf.md)
 - [GetTimestampForHeight200Response](docs/GetTimestampForHeight200Response.md)
 - [GetTimestampForHeight200ResponseAllOf](docs/GetTimestampForHeight200ResponseAllOf.md)
 - [GetTimestampForHeightRequest](docs/GetTimestampForHeightRequest.md)
 - [GetTransactionCount200Response](docs/GetTransactionCount200Response.md)
 - [GetTransactionCount200ResponseAllOf](docs/GetTransactionCount200ResponseAllOf.md)
 - [GetTransactionMemo200Response](docs/GetTransactionMemo200Response.md)
 - [GetTransactionRequest](docs/GetTransactionRequest.md)
 - [GetTransactions200Response](docs/GetTransactions200Response.md)
 - [GetTransactions200ResponseAllOf](docs/GetTransactions200ResponseAllOf.md)
 - [GetTransactionsRequest](docs/GetTransactionsRequest.md)
 - [GetWalletBalance200Response](docs/GetWalletBalance200Response.md)
 - [GetWalletBalance200ResponseAllOf](docs/GetWalletBalance200ResponseAllOf.md)
 - [GetWallets200Response](docs/GetWallets200Response.md)
 - [GetWallets200ResponseAllOf](docs/GetWallets200ResponseAllOf.md)
 - [GetWalletsRequest](docs/GetWalletsRequest.md)
 - [LineageProof](docs/LineageProof.md)
 - [LogIn200Response](docs/LogIn200Response.md)
 - [LogIn200ResponseAllOf](docs/LogIn200ResponseAllOf.md)
 - [LogInRequest](docs/LogInRequest.md)
 - [Mirror](docs/Mirror.md)
 - [ModelApiResponse](docs/ModelApiResponse.md)
 - [NetworkInfo](docs/NetworkInfo.md)
 - [NftAddUriRequest](docs/NftAddUriRequest.md)
 - [NftCalculateRoyalties200Response](docs/NftCalculateRoyalties200Response.md)
 - [NftCalculateRoyalties200ResponseAllOfInner](docs/NftCalculateRoyalties200ResponseAllOfInner.md)
 - [NftCalculateRoyaltiesRequest](docs/NftCalculateRoyaltiesRequest.md)
 - [NftCalculateRoyaltiesRequestFungibleAssetsInner](docs/NftCalculateRoyaltiesRequestFungibleAssetsInner.md)
 - [NftCalculateRoyaltiesRequestRoyaltyAssetsInner](docs/NftCalculateRoyaltiesRequestRoyaltyAssetsInner.md)
 - [NftCountNfts200Response](docs/NftCountNfts200Response.md)
 - [NftCountNfts200ResponseAllOf](docs/NftCountNfts200ResponseAllOf.md)
 - [NftGetByDid200Response](docs/NftGetByDid200Response.md)
 - [NftGetByDid200ResponseAllOf](docs/NftGetByDid200ResponseAllOf.md)
 - [NftGetByDidRequest](docs/NftGetByDidRequest.md)
 - [NftGetInfo200Response](docs/NftGetInfo200Response.md)
 - [NftGetInfo200ResponseAllOf](docs/NftGetInfo200ResponseAllOf.md)
 - [NftGetInfoRequest](docs/NftGetInfoRequest.md)
 - [NftGetNfts200Response](docs/NftGetNfts200Response.md)
 - [NftGetNfts200ResponseAllOf](docs/NftGetNfts200ResponseAllOf.md)
 - [NftGetNftsRequest](docs/NftGetNftsRequest.md)
 - [NftGetWalletDid200Response](docs/NftGetWalletDid200Response.md)
 - [NftGetWalletDid200ResponseAllOf](docs/NftGetWalletDid200ResponseAllOf.md)
 - [NftGetWalletDidRequest](docs/NftGetWalletDidRequest.md)
 - [NftGetWalletsWithDids200Response](docs/NftGetWalletsWithDids200Response.md)
 - [NftGetWalletsWithDids200ResponseAllOf](docs/NftGetWalletsWithDids200ResponseAllOf.md)
 - [NftGetWalletsWithDids200ResponseAllOfNftWalletsInner](docs/NftGetWalletsWithDids200ResponseAllOfNftWalletsInner.md)
 - [NftInfo](docs/NftInfo.md)
 - [NftMintBulk200Response](docs/NftMintBulk200Response.md)
 - [NftMintBulk200ResponseAllOf](docs/NftMintBulk200ResponseAllOf.md)
 - [NftMintBulkRequest](docs/NftMintBulkRequest.md)
 - [NftMintBulkRequestMetadataListInner](docs/NftMintBulkRequestMetadataListInner.md)
 - [NftMintNft200Response](docs/NftMintNft200Response.md)
 - [NftMintNft200ResponseAllOf](docs/NftMintNft200ResponseAllOf.md)
 - [NftMintNftRequest](docs/NftMintNftRequest.md)
 - [NftSetDidBulk200Response](docs/NftSetDidBulk200Response.md)
 - [NftSetDidBulk200ResponseAllOf](docs/NftSetDidBulk200ResponseAllOf.md)
 - [NftSetDidBulkRequest](docs/NftSetDidBulkRequest.md)
 - [NftSetDidBulkRequestNftCoinListInner](docs/NftSetDidBulkRequestNftCoinListInner.md)
 - [NftSetNftDid200Response](docs/NftSetNftDid200Response.md)
 - [NftSetNftDid200ResponseAllOf](docs/NftSetNftDid200ResponseAllOf.md)
 - [NftSetNftDidRequest](docs/NftSetNftDidRequest.md)
 - [NftSetNftStatusRequest](docs/NftSetNftStatusRequest.md)
 - [NftTransferBulkRequest](docs/NftTransferBulkRequest.md)
 - [NftTransferNftRequest](docs/NftTransferNftRequest.md)
 - [NodeType](docs/NodeType.md)
 - [OpenConnectionRequest](docs/OpenConnectionRequest.md)
 - [PoolSingletonState](docs/PoolSingletonState.md)
 - [PoolState](docs/PoolState.md)
 - [PoolWalletInfo](docs/PoolWalletInfo.md)
 - [PrivateKey](docs/PrivateKey.md)
 - [PushTransactionsRequest](docs/PushTransactionsRequest.md)
 - [PuzzleAnnouncement](docs/PuzzleAnnouncement.md)
 - [PwAbsorbRewards200Response](docs/PwAbsorbRewards200Response.md)
 - [PwAbsorbRewards200ResponseAllOf](docs/PwAbsorbRewards200ResponseAllOf.md)
 - [PwJoinPool200Response](docs/PwJoinPool200Response.md)
 - [PwJoinPool200ResponseAllOf](docs/PwJoinPool200ResponseAllOf.md)
 - [PwJoinPoolRequest](docs/PwJoinPoolRequest.md)
 - [PwSelfPoolRequest](docs/PwSelfPoolRequest.md)
 - [PwStatus200Response](docs/PwStatus200Response.md)
 - [PwStatus200ResponseAllOf](docs/PwStatus200ResponseAllOf.md)
 - [SelectCoins200Response](docs/SelectCoins200Response.md)
 - [SelectCoins200ResponseAllOf](docs/SelectCoins200ResponseAllOf.md)
 - [SelectCoinsRequest](docs/SelectCoinsRequest.md)
 - [SendNotification200Response](docs/SendNotification200Response.md)
 - [SendNotification200ResponseAllOf](docs/SendNotification200ResponseAllOf.md)
 - [SendNotificationRequest](docs/SendNotificationRequest.md)
 - [SendTransactionMultiRequest](docs/SendTransactionMultiRequest.md)
 - [SendTransactionRequest](docs/SendTransactionRequest.md)
 - [SetWalletResyncOnStartupRequest](docs/SetWalletResyncOnStartupRequest.md)
 - [SignMessageByAddress200Response](docs/SignMessageByAddress200Response.md)
 - [SignMessageByAddress200ResponseAllOf](docs/SignMessageByAddress200ResponseAllOf.md)
 - [SignMessageByAddressRequest](docs/SignMessageByAddressRequest.md)
 - [SignMessageById200Response](docs/SignMessageById200Response.md)
 - [SignMessageById200ResponseAllOf](docs/SignMessageById200ResponseAllOf.md)
 - [SignMessageByIdRequest](docs/SignMessageByIdRequest.md)
 - [SingletonRecord](docs/SingletonRecord.md)
 - [SpendBundle](docs/SpendBundle.md)
 - [TakeOffer200Response](docs/TakeOffer200Response.md)
 - [TakeOffer200ResponseAllOf](docs/TakeOffer200ResponseAllOf.md)
 - [TakeOfferRequest](docs/TakeOfferRequest.md)
 - [Token](docs/Token.md)
 - [TradeRecord](docs/TradeRecord.md)
 - [TradeStatus](docs/TradeStatus.md)
 - [TransactionInput](docs/TransactionInput.md)
 - [TransactionRecord](docs/TransactionRecord.md)
 - [TransactionType](docs/TransactionType.md)
 - [VerifySignature200Response](docs/VerifySignature200Response.md)
 - [VerifySignatureRequest](docs/VerifySignatureRequest.md)
 - [WalletBalance](docs/WalletBalance.md)
 - [WalletGetNetworkInfo200Response](docs/WalletGetNetworkInfo200Response.md)
 - [WalletInfo](docs/WalletInfo.md)
 - [WalletPushTxRequest](docs/WalletPushTxRequest.md)
 - [WalletType](docs/WalletType.md)


## Documentation for Authorization

Authentication schemes defined for the API:
### bearerAuth

- **Type**: HTTP basic authentication


## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author

hello@chia.net

