# KeyManagementApi

All URIs are relative to *https://localhost:9256*

| Method | HTTP request | Description |
|------------- | ------------- | -------------|
| [**addKey**](KeyManagementApi.md#addKey) | **POST** /add_key | Generates a new mnemonic phrase. |
| [**checkDeleteKey**](KeyManagementApi.md#checkDeleteKey) | **POST** /check_delete_key | Determines if it is safe to delete a private key. |
| [**deleteKey**](KeyManagementApi.md#deleteKey) | **POST** /delete_key | Deletes all keys which have the given public key fingerprint. |
| [**generateMnemonic**](KeyManagementApi.md#generateMnemonic) | **POST** /generate_mnemonic | Generates a new mnemonic phrase. |
| [**getLoggedInFingerprint**](KeyManagementApi.md#getLoggedInFingerprint) | **POST** /get_logged_in_fingerprint | Retrieves the logged in fingerprint. |
| [**getPrivateKey**](KeyManagementApi.md#getPrivateKey) | **POST** /get_private_key | Retrieves the private key by fingerprint. |
| [**getPublicKeys**](KeyManagementApi.md#getPublicKeys) | **POST** /get_public_keys | Retrieves all public keys on the node. |
| [**logIn**](KeyManagementApi.md#logIn) | **POST** /log_in | Logs in the wallet with a specific key. |
| [**verifySignature**](KeyManagementApi.md#verifySignature) | **POST** /verify_signature | Given a public key, message and signature, verify if it is valid. |
| [**walletDeleteAllKeys**](KeyManagementApi.md#walletDeleteAllKeys) | **POST** /delete_all_keys | Deletes all keys from the keychain. |


<a name="addKey"></a>
# **addKey**
> AddKey200Response addKey(requestBody)

Generates a new mnemonic phrase.

Generates a new mnemonic phrase.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.KeyManagementApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://localhost:9256");
    

    KeyManagementApi apiInstance = new KeyManagementApi(defaultClient);
    List<String> requestBody = Arrays.asList(); // List<String> | The mnemonic phrase.
    try {
      AddKey200Response result = apiInstance.addKey(requestBody);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling KeyManagementApi#addKey");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

| Name | Type | Description  | Notes |
|------------- | ------------- | ------------- | -------------|
| **requestBody** | [**List&lt;String&gt;**](String.md)| The mnemonic phrase. | |

### Return type

[**AddKey200Response**](AddKey200Response.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | OK |  -  |

<a name="checkDeleteKey"></a>
# **checkDeleteKey**
> CheckDeleteKey200Response checkDeleteKey(logInRequest)

Determines if it is safe to delete a private key.

Determines if it is safe to delete a private key. Returns whether it is used for farming, pooling, or has a balance.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.KeyManagementApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://localhost:9256");
    

    KeyManagementApi apiInstance = new KeyManagementApi(defaultClient);
    LogInRequest logInRequest = new LogInRequest(); // LogInRequest | Request body with a wallet fingerprint.
    try {
      CheckDeleteKey200Response result = apiInstance.checkDeleteKey(logInRequest);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling KeyManagementApi#checkDeleteKey");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

| Name | Type | Description  | Notes |
|------------- | ------------- | ------------- | -------------|
| **logInRequest** | [**LogInRequest**](LogInRequest.md)| Request body with a wallet fingerprint. | |

### Return type

[**CheckDeleteKey200Response**](CheckDeleteKey200Response.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | OK |  -  |

<a name="deleteKey"></a>
# **deleteKey**
> ModelApiResponse deleteKey(logInRequest)

Deletes all keys which have the given public key fingerprint.

Deletes all keys which have the given public key fingerprint.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.KeyManagementApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://localhost:9256");
    

    KeyManagementApi apiInstance = new KeyManagementApi(defaultClient);
    LogInRequest logInRequest = new LogInRequest(); // LogInRequest | Request body with a wallet fingerprint.
    try {
      ModelApiResponse result = apiInstance.deleteKey(logInRequest);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling KeyManagementApi#deleteKey");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

| Name | Type | Description  | Notes |
|------------- | ------------- | ------------- | -------------|
| **logInRequest** | [**LogInRequest**](LogInRequest.md)| Request body with a wallet fingerprint. | |

### Return type

[**ModelApiResponse**](ModelApiResponse.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | OK response without return values |  -  |

<a name="generateMnemonic"></a>
# **generateMnemonic**
> List&lt;String&gt; generateMnemonic(body)

Generates a new mnemonic phrase.

Generates a new mnemonic phrase.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.KeyManagementApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://localhost:9256");
    

    KeyManagementApi apiInstance = new KeyManagementApi(defaultClient);
    Object body = null; // Object | Empty request body
    try {
      List<String> result = apiInstance.generateMnemonic(body);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling KeyManagementApi#generateMnemonic");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

| Name | Type | Description  | Notes |
|------------- | ------------- | ------------- | -------------|
| **body** | **Object**| Empty request body | |

### Return type

**List&lt;String&gt;**

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | OK |  -  |

<a name="getLoggedInFingerprint"></a>
# **getLoggedInFingerprint**
> LogIn200Response getLoggedInFingerprint(body)

Retrieves the logged in fingerprint.

Retrieves the logged in fingerprint.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.KeyManagementApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://localhost:9256");
    

    KeyManagementApi apiInstance = new KeyManagementApi(defaultClient);
    Object body = null; // Object | Empty request body
    try {
      LogIn200Response result = apiInstance.getLoggedInFingerprint(body);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling KeyManagementApi#getLoggedInFingerprint");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

| Name | Type | Description  | Notes |
|------------- | ------------- | ------------- | -------------|
| **body** | **Object**| Empty request body | |

### Return type

[**LogIn200Response**](LogIn200Response.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | OK |  -  |

<a name="getPrivateKey"></a>
# **getPrivateKey**
> GetPrivateKey200Response getPrivateKey(logInRequest)

Retrieves the private key by fingerprint.

Retrieves the private key by fingerprint.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.KeyManagementApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://localhost:9256");
    

    KeyManagementApi apiInstance = new KeyManagementApi(defaultClient);
    LogInRequest logInRequest = new LogInRequest(); // LogInRequest | Request body with a wallet fingerprint.
    try {
      GetPrivateKey200Response result = apiInstance.getPrivateKey(logInRequest);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling KeyManagementApi#getPrivateKey");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

| Name | Type | Description  | Notes |
|------------- | ------------- | ------------- | -------------|
| **logInRequest** | [**LogInRequest**](LogInRequest.md)| Request body with a wallet fingerprint. | |

### Return type

[**GetPrivateKey200Response**](GetPrivateKey200Response.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | OK |  -  |

<a name="getPublicKeys"></a>
# **getPublicKeys**
> GetPublicKeys200Response getPublicKeys(body)

Retrieves all public keys on the node.

Retrieves all public keys on the node.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.KeyManagementApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://localhost:9256");
    

    KeyManagementApi apiInstance = new KeyManagementApi(defaultClient);
    Object body = null; // Object | Empty request body
    try {
      GetPublicKeys200Response result = apiInstance.getPublicKeys(body);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling KeyManagementApi#getPublicKeys");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

| Name | Type | Description  | Notes |
|------------- | ------------- | ------------- | -------------|
| **body** | **Object**| Empty request body | |

### Return type

[**GetPublicKeys200Response**](GetPublicKeys200Response.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | OK |  -  |

<a name="logIn"></a>
# **logIn**
> LogIn200Response logIn(logInRequest)

Logs in the wallet with a specific key.

Logs in the wallet with a specific key.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.KeyManagementApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://localhost:9256");
    

    KeyManagementApi apiInstance = new KeyManagementApi(defaultClient);
    LogInRequest logInRequest = new LogInRequest(); // LogInRequest | Request body with a wallet fingerprint.
    try {
      LogIn200Response result = apiInstance.logIn(logInRequest);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling KeyManagementApi#logIn");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

| Name | Type | Description  | Notes |
|------------- | ------------- | ------------- | -------------|
| **logInRequest** | [**LogInRequest**](LogInRequest.md)| Request body with a wallet fingerprint. | |

### Return type

[**LogIn200Response**](LogIn200Response.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | OK |  -  |

<a name="verifySignature"></a>
# **verifySignature**
> VerifySignature200Response verifySignature(verifySignatureRequest)

Given a public key, message and signature, verify if it is valid.

Given a public key, message and signature, verify if it is valid.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.KeyManagementApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://localhost:9256");
    

    KeyManagementApi apiInstance = new KeyManagementApi(defaultClient);
    VerifySignatureRequest verifySignatureRequest = new VerifySignatureRequest(); // VerifySignatureRequest | The coin names.
    try {
      VerifySignature200Response result = apiInstance.verifySignature(verifySignatureRequest);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling KeyManagementApi#verifySignature");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

| Name | Type | Description  | Notes |
|------------- | ------------- | ------------- | -------------|
| **verifySignatureRequest** | [**VerifySignatureRequest**](VerifySignatureRequest.md)| The coin names. | |

### Return type

[**VerifySignature200Response**](VerifySignature200Response.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | OK |  -  |

<a name="walletDeleteAllKeys"></a>
# **walletDeleteAllKeys**
> ModelApiResponse walletDeleteAllKeys(body)

Deletes all keys from the keychain.

Deletes all keys from the keychain.

### Example
```java
// Import classes:
import org.openapitools.client.ApiClient;
import org.openapitools.client.ApiException;
import org.openapitools.client.Configuration;
import org.openapitools.client.auth.*;
import org.openapitools.client.models.*;
import org.openapitools.client.api.KeyManagementApi;

public class Example {
  public static void main(String[] args) {
    ApiClient defaultClient = Configuration.getDefaultApiClient();
    defaultClient.setBasePath("https://localhost:9256");
    

    KeyManagementApi apiInstance = new KeyManagementApi(defaultClient);
    Object body = null; // Object | Empty request body
    try {
      ModelApiResponse result = apiInstance.walletDeleteAllKeys(body);
      System.out.println(result);
    } catch (ApiException e) {
      System.err.println("Exception when calling KeyManagementApi#walletDeleteAllKeys");
      System.err.println("Status code: " + e.getCode());
      System.err.println("Reason: " + e.getResponseBody());
      System.err.println("Response headers: " + e.getResponseHeaders());
      e.printStackTrace();
    }
  }
}
```

### Parameters

| Name | Type | Description  | Notes |
|------------- | ------------- | ------------- | -------------|
| **body** | **Object**| Empty request body | |

### Return type

[**ModelApiResponse**](ModelApiResponse.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details
| Status code | Description | Response headers |
|-------------|-------------|------------------|
| **200** | OK response without return values |  -  |

